@@ -58,9 +58,10 @@
 #include "kmymoneysettings.h"
 #include "transactioneditor.h"
 #include "stdtransactioneditor.h"
-#include "kmymoneyedit.h"
+#include "amountedit.h"
 #include "kaccountselectdlg.h"
 #include "knewaccountwizard.h"
+#include "knewinvestmentwizard.h"
 #include "transactionmatcher.h"
 #include "kenterscheduledlg.h"
 #include "kmymoneyaccountcombo.h"
@@ -227,7 +228,7 @@ void MyMoneyStatementReader::Private::previouslyUsedCategories(const QString& in
       MyMoneySplit s = (*it_t).second;
 
       acc = file->account(s.accountId());
-      // stock split shouldn't be fee or interest bacause it won't play nice with dissectTransaction
+      // stock split shouldn't be fee or interest because it won't play nice with dissectTransaction
       // it was caused by processTransactionEntry adding splits in wrong order != with manual transaction entering
       if (acc.accountGroup() == Account::Type::Expense || acc.accountGroup() == Account::Type::Income) {
         foreach (auto sNew , t.splits()) {
@@ -289,31 +290,40 @@ void MyMoneyStatementReader::Private::scanCategories(QString& id, const MyMoneyA
 
 void MyMoneyStatementReader::Private::assignUniqueBankID(MyMoneySplit& s, const MyMoneyStatement::Transaction& t_in)
 {
-  if (! t_in.m_strBankID.isEmpty()) {
-    // make sure that id's are unique from this point on by appending a -#
-    // postfix if needed
-    QString base(t_in.m_strBankID);
-    QString hash(base);
-    int idx = 1;
-    for (;;) {
-      QMap<QString, bool>::const_iterator it;
-      it = uniqIds.constFind(hash);
-      if (it == uniqIds.constEnd()) {
-        uniqIds[hash] = true;
-        break;
-      }
-      hash = QString("%1-%2").arg(base).arg(idx);
-      ++idx;
-    }
+  QString base(t_in.m_strBankID);
 
-    s.setBankID(hash);
+  if (base.isEmpty()) {
+    // in case the importer did not assign a bankID, we will do it here
+    // we use the same algorith as used in the KBanking plugin as this
+    // has been served well for a long time already.
+    auto h = MyMoneyTransaction::hash(t_in.m_strPayee.trimmed());
+    h = MyMoneyTransaction::hash(t_in.m_strMemo, h);
+    h = MyMoneyTransaction::hash(t_in.m_amount.toString(), h);
+    base = QString("%1-%2-%3").arg(s.accountId(), t_in.m_datePosted.toString(Qt::ISODate)).arg(h, 7, 16, QChar('0'));
   }
+
+  // make sure that id's are unique from this point on by appending a -#
+  // postfix if needed
+  QString hash(base);
+  int idx = 1;
+  for (;;) {
+    QMap<QString, bool>::const_iterator it;
+    it = uniqIds.constFind(hash);
+    if (it == uniqIds.constEnd()) {
+      uniqIds[hash] = true;
+      break;
+    }
+    hash = QString("%1-%2").arg(base).arg(idx);
+    ++idx;
+  }
+
+  s.setBankID(hash);
 }
 
 void MyMoneyStatementReader::Private::setupPrice(MyMoneySplit &s, const MyMoneyAccount &splitAccount, const MyMoneyAccount &transactionAccount, const QDate &postDate)
 {
   if (transactionAccount.currencyId() != splitAccount.currencyId()) {
-    // a currency converstion is needed assume that split has already a proper value
+    // a currency conversion is needed assume that split has already a proper value
     MyMoneyFile* file = MyMoneyFile::instance();
     MyMoneySecurity toCurrency = file->security(splitAccount.currencyId());
     MyMoneySecurity fromCurrency = file->security(transactionAccount.currencyId());
@@ -381,7 +391,7 @@ QStringList MyMoneyStatementReader::importStatement(const MyMoneyStatement& s, b
   // keep a copy of the statement
   if (KMyMoneySettings::logImportedStatements()) {
     auto logFile = QString::fromLatin1("%1/kmm-statement-%2.txt").arg(KMyMoneySettings::logPath(),
-                                                                      QDateTime::currentDateTimeUtc().toString(QStringLiteral("yyyy-MM-dd hh-mm-ss")));
+                                                                      QDateTime::currentDateTimeUtc().toString(QStringLiteral("yyyy-MM-dd hh-mm-ss.zzz")));
     MyMoneyStatement::writeXMLFile(s, logFile);
  }
 
@@ -695,6 +705,9 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
     if (brokerageactid.isEmpty()) {
       brokerageactid = file->nameToAccount(thisaccount.brokerageName());
     }
+    if (brokerageactid.isEmpty()) {
+      brokerageactid = file->accountByName(thisaccount.brokerageName()).id();
+    }
     if (brokerageactid.isEmpty()) {
       brokerageactid = SelectBrokerageAccount();
     }
@@ -725,7 +738,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
         }
       }
 
-      // If there was no stock account under the m_acccount investment account,
+      // If there was no stock account under the m_account investment account,
       // add one using the security.
       if (!found) {
         // The security should always be available, because the statement file
@@ -758,16 +771,11 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
           }
           // this security does not exist in the file.
           else {
-            // This should be rare.  A statement should have a security entry for any
-            // of the securities referred to in the transactions.  The only way to get
-            // here is if that's NOT the case.
-            int ret = KMessageBox::warningContinueCancel(0, i18n("<center>This investment account does not contain the \"%1\" security.</center>"
-                      "<center>Transactions involving this security will be ignored.</center>", statementTransactionUnderImport.m_strSecurity),
-                      i18n("Security not found"), KStandardGuiItem::cont(), KStandardGuiItem::cancel());
-            if (ret == KMessageBox::Cancel) {
-              m_userAbort = true;
-            }
-            return;
+            thisaccount = MyMoneyAccount();
+            thisaccount.setName(statementTransactionUnderImport.m_strSecurity);
+
+            qDebug() << Q_FUNC_INFO << ": opening new investment wizard for security " << statementTransactionUnderImport.m_strSecurity << " under account " << d->m_account.id();
+            KNewInvestmentWizard::newInvestment(thisaccount, d->m_account);
           }
         }
       }
@@ -777,15 +785,14 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
           && statementTransactionUnderImport.m_eAction != eMyMoney::Transaction::Action::Shrsout) {
         // update the price, while we're here.  in the future, this should be
         // an option
-        QString basecurrencyid = file->baseCurrency().id();
-        const MyMoneyPrice &price = file->price(currencyid, basecurrencyid, statementTransactionUnderImport.m_datePosted, true);
+        const MyMoneyPrice &price = file->price(currencyid, transactionUnderImport.commodity(), statementTransactionUnderImport.m_datePosted, true);
         if (!price.isValid()  && ((!statementTransactionUnderImport.m_amount.isZero() && !statementTransactionUnderImport.m_shares.isZero()) || !statementTransactionUnderImport.m_price.isZero())) {
           MyMoneyPrice newprice;
           if (!statementTransactionUnderImport.m_price.isZero()) {
-            newprice = MyMoneyPrice(currencyid, basecurrencyid, statementTransactionUnderImport.m_datePosted,
+            newprice = MyMoneyPrice(currencyid, transactionUnderImport.commodity(), statementTransactionUnderImport.m_datePosted,
                                     statementTransactionUnderImport.m_price.abs(), i18n("Statement Importer"));
           } else {
-            newprice = MyMoneyPrice(currencyid, basecurrencyid, statementTransactionUnderImport.m_datePosted,
+            newprice = MyMoneyPrice(currencyid, transactionUnderImport.commodity(), statementTransactionUnderImport.m_datePosted,
                                     (statementTransactionUnderImport.m_amount / statementTransactionUnderImport.m_shares).abs(), i18n("Statement Importer"));
           }
           file->addPrice(newprice);
@@ -1120,7 +1127,7 @@ void MyMoneyStatementReader::processTransactionEntry(const MyMoneyStatement::Tra
       // handle it.
       //
       const MyMoneyPayee& payeeObj = MyMoneyFile::instance()->payee(payeeid);
-      if (statementTransactionUnderImport.m_listSplits.isEmpty() && payeeObj.defaultAccountEnabled()) {
+      if (statementTransactionUnderImport.m_listSplits.isEmpty() && !payeeObj.defaultAccountId().isEmpty()) {
         MyMoneyAccount splitAccount = file->account(payeeObj.defaultAccountId());
         MyMoneySplit s;
         s.setReconcileFlag(eMyMoney::Split::State::Cleared);
@@ -1503,7 +1510,7 @@ void MyMoneyStatementReader::handleMatchingOfScheduledTransaction(TransactionMat
             // sure to use only the absolute value of the amount, because
             // the editor keeps the sign in a different position (deposit,
             // withdrawal tab)
-            KMyMoneyEdit* amount = dynamic_cast<KMyMoneyEdit*>(se->haveWidget("amount"));
+            AmountEdit* amount = dynamic_cast<AmountEdit*>(se->haveWidget("amount"));
             if (amount) {
               amount->setValue(importedSplit.shares().abs());
               se->slotUpdateAmount(importedSplit.shares().abs().toString());
