@@ -283,8 +283,15 @@ bool WebPriceQuote::launchNative(const QString& _webID, const QString& _kmmID, c
     QString program;
     QStringList arguments = url.toLocalFile().split(' ', QString::SkipEmptyParts);
     if (!arguments.isEmpty()) {
+#ifndef IS_APPIMAGE
         program = arguments.first();
         arguments.removeFirst();
+#else
+        program = QStringLiteral("/bin/sh");
+        arguments.clear();
+        arguments << QStringLiteral("-c");
+        arguments << url.toLocalFile();
+#endif
     }
     d->m_filter.setWebID(d->m_webID);
 
@@ -435,7 +442,7 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
 
   if (! quotedata.isEmpty()) {
     if (!d->m_source.m_skipStripping) {
-      // First, remove extranous non-data elements
+      // First, remove extraneous non-data elements
 
       // HTML tags
       quotedata.remove(QRegularExpression("<[^>]*>"));
@@ -740,6 +747,18 @@ const QMap<QString, WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources()
                                                         "%d.%m.%y",   // dateformat
                                                         true
                                                         );
+  // The following was contributed by Brendan Coupe <Brendan@CoupeWare.com>
+  result["Yahoo Finance"] = WebPriceQuoteSource("Yahoo Finance",
+                                                "https://query1.finance.yahoo.com/v7/finance/quote?fields=regularMarketPrice&symbols=%1",
+                                                QString(),
+                                                "%1",  // webIDRegExp
+                                                WebPriceQuoteSource::identifyBy::Symbol,
+                                                "\"regularMarketPrice\":((\\d+|\\d{1,3}(?:[,]\\d{3})).\\d+)",  // priceregexp
+                                                "\"regularMarketTime\":([\\d]+)",  // dateregexp
+                                                QString(),
+                                                true
+                                                );
+
   return result;
 }
 
@@ -1049,10 +1068,10 @@ const QString FinanceQuoteProcess::niceName(const QString& crypticName) const
 // Universal date converter
 //
 
-// In 'strict' mode, this is designed to be compatable with the QIF profile date
+// In 'strict' mode, this is designed to be compatible with the QIF profile date
 // converter.  However, that converter deals with the concept of an apostrophe
 // format in a way I don't understand.  So for the moment, they are 99%
-// compatable, waiting on that issue. (acejones)
+// compatible, waiting on that issue. (acejones)
 
 const QDate MyMoneyDateFormat::convertString(const QString& _in, bool _strict, unsigned _centurymidpoint) const
 {
