@@ -46,7 +46,7 @@
 #include "transactioneditorcontainer.h"
 #include "kmymoneycategory.h"
 #include "kmymoneydateinput.h"
-#include "kmymoneyedit.h"
+#include "amountedit.h"
 #include "kmymoneyaccountselector.h"
 #include "kmymoneymvccombo.h"
 #include "mymoneyfile.h"
@@ -74,7 +74,7 @@ class InvestTransactionEditorPrivate : public TransactionEditorPrivate
 public:
   explicit  InvestTransactionEditorPrivate(InvestTransactionEditor* qq) :
       TransactionEditorPrivate(qq),
-      m_activity(0),
+      m_activity(nullptr),
       m_phonyAccount(MyMoneyAccount("Phony-ID", MyMoneyAccount())),
       m_transactionType(eMyMoney::Split::InvestmentTransactionType::BuyShares)
   {
@@ -199,7 +199,7 @@ public:
       if (w)
         w->setFocus();
 
-      auto amount = dynamic_cast<KMyMoneyEdit*>(q->haveWidget(amountWidgetName));
+      auto amount = dynamic_cast<AmountEdit*>(q->haveWidget(amountWidgetName));
       if (!amount)
         return rc;
 
@@ -258,7 +258,7 @@ public:
       }
 
       // focus jumps into the memo field
-      if ((w = q->haveWidget("memo")) != 0) {
+      if ((w = q->haveWidget("memo")) != nullptr) {
         w->setFocus();
       }
 
@@ -271,8 +271,8 @@ public:
   {
     Q_Q(InvestTransactionEditor);
     if (auto label = dynamic_cast<QLabel*>(q->haveWidget("price-label"))) {
-      auto sharesEdit = dynamic_cast<KMyMoneyEdit*>(q->haveWidget("shares"));
-      auto priceEdit = dynamic_cast<KMyMoneyEdit*>(q->haveWidget("price"));
+      auto sharesEdit = dynamic_cast<AmountEdit*>(q->haveWidget("shares"));
+      auto priceEdit = dynamic_cast<AmountEdit*>(q->haveWidget("price"));
 
       if (!sharesEdit || !priceEdit)
         return;
@@ -332,7 +332,7 @@ InvestTransactionEditor::InvestTransactionEditor(TransactionEditorContainer* reg
                       lastPostDate)
 {
   Q_D(InvestTransactionEditor);
-  // after the gometries of the container are updated hide the widgets which are not needed by the current activity
+  // after the geometries of the container are updated hide the widgets which are not needed by the current activity
   connect(d->m_regForm, &TransactionEditorContainer::geometriesUpdated, this, &InvestTransactionEditor::slotTransactionContainerGeometriesUpdated);
 
   // dissect the transaction into its type, splits, currency, security etc.
@@ -357,7 +357,8 @@ void InvestTransactionEditor::createEditWidgets()
   connect(activity, &KMyMoneyActivityCombo::activitySelected, this, &InvestTransactionEditor::slotUpdateActivity);
   connect(activity, &KMyMoneyActivityCombo::activitySelected, this, &InvestTransactionEditor::slotUpdateButtonState);
 
-  d->m_editWidgets["postdate"] = new KMyMoneyDateInput;
+  auto postDate = d->m_editWidgets["postdate"] = new KMyMoneyDateInput;
+  connect(postDate, SIGNAL(dateChanged(QDate)), this, SLOT(slotUpdateButtonState()));
 
   auto security = new KMyMoneySecurity;
   security->setObjectName("security");
@@ -413,39 +414,39 @@ void InvestTransactionEditor::createEditWidgets()
   d->m_activity->memoText().clear();
   d->m_activity->memoChanged() = false;
 
-  KMyMoneyEdit* value = new KMyMoneyEdit;
+  AmountEdit* value = new AmountEdit;
   value->setObjectName("shares");
   value->setPlaceholderText(i18n("Shares"));
-  value->setResetButtonVisible(false);
+  value->setCalculatorButtonVisible(true);
   d->m_editWidgets["shares"] = value;
-  connect(value, &KMyMoneyEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
-  connect(value, &KMyMoneyEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
+  connect(value, &AmountEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
+  connect(value, &AmountEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
 
-  value = new KMyMoneyEdit;
+  value = new AmountEdit;
   value->setObjectName("price");
   value->setPlaceholderText(i18n("Price"));
-  value->setResetButtonVisible(false);
+  value->setCalculatorButtonVisible(true);
   d->m_editWidgets["price"] = value;
-  connect(value, &KMyMoneyEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
-  connect(value, &KMyMoneyEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
+  connect(value, &AmountEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
+  connect(value, &AmountEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
 
-  value = new KMyMoneyEdit;
+  value = new AmountEdit;
   value->setObjectName("fee-amount");
   // TODO once we have the selected transactions as array of Transaction
   // we can allow multiple splits for fee and interest
-  value->setResetButtonVisible(false);
+  value->setCalculatorButtonVisible(true);
   d->m_editWidgets["fee-amount"] = value;
-  connect(value, &KMyMoneyEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
-  connect(value, &KMyMoneyEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
+  connect(value, &AmountEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
+  connect(value, &AmountEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
 
-  value = new KMyMoneyEdit;
+  value = new AmountEdit;
   value->setObjectName("interest-amount");
   // TODO once we have the selected transactions as array of Transaction
   // we can allow multiple splits for fee and interest
-  value->setResetButtonVisible(false);
+  value->setCalculatorButtonVisible(true);
   d->m_editWidgets["interest-amount"] = value;
-  connect(value, &KMyMoneyEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
-  connect(value, &KMyMoneyEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
+  connect(value, &AmountEdit::textChanged, this, &InvestTransactionEditor::slotUpdateButtonState);
+  connect(value, &AmountEdit::valueChanged, this, &InvestTransactionEditor::slotUpdateTotalAmount);
 
   auto reconcile = new KMyMoneyReconcileCombo;
   reconcile->setObjectName("reconcile");
@@ -480,7 +481,7 @@ void InvestTransactionEditor::createEditWidgets()
   d->m_editWidgets["fee-label"] = label = new QLabel(i18n("Fees"));
   label->setAlignment(Qt::AlignVCenter);
 
-  d->m_editWidgets["fee-amount-label"] = label = new QLabel("");
+  d->m_editWidgets["fee-amount-label"] = label = new QLabel(QString());
   label->setAlignment(Qt::AlignVCenter);
 
   d->m_editWidgets["interest-label"] = label = new QLabel(i18n("Interest"));
@@ -492,7 +493,7 @@ void InvestTransactionEditor::createEditWidgets()
   d->m_editWidgets["memo-label"] = label = new QLabel(i18n("Memo"));
   label->setAlignment(Qt::AlignVCenter);
 
-  d->m_editWidgets["total"] = label = new QLabel("");
+  d->m_editWidgets["total"] = label = new QLabel(QString());
   label->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
 
   d->m_editWidgets["total-label"] = label = new QLabel(i18nc("Total value", "Total"));
@@ -617,7 +618,7 @@ void InvestTransactionEditor::loadEditWidgets()
   auto activity = dynamic_cast<KMyMoneyActivityCombo*>(haveWidget("activity"));
   auto asset = dynamic_cast<KMyMoneyCategory*>(haveWidget("asset-account"));
   auto memo = dynamic_cast<KTextEdit*>(d->m_editWidgets["memo"]);
-  KMyMoneyEdit* value;
+  AmountEdit* value;
   auto interest = dynamic_cast<KMyMoneyCategory*>(haveWidget("interest-account"));
   auto fees = dynamic_cast<KMyMoneyCategory*>(haveWidget("fee-account"));
 
@@ -695,7 +696,7 @@ void InvestTransactionEditor::loadEditWidgets()
     // shares
     // don't set the value if the number of shares is zero so that
     // we can see the hint
-    value = dynamic_cast<KMyMoneyEdit*>(haveWidget("shares"));
+    value = dynamic_cast<AmountEdit*>(haveWidget("shares"));
     if (!value)
       return;
     if (typeid(*(d->m_activity)) != typeid(Invest::Split(this)))
@@ -710,15 +711,17 @@ void InvestTransactionEditor::loadEditWidgets()
     d->updatePriceMode(d->m_split);
 
     // fee amount
-    value = dynamic_cast<KMyMoneyEdit*>(haveWidget("fee-amount"));
+    value = dynamic_cast<AmountEdit*>(haveWidget("fee-amount"));
     if (!value)
       return;
+    value->setPrecision(MyMoneyMoney::denomToPrec(d->m_currency.smallestAccountFraction()));
     value->setValue(d->subtotal(d->m_feeSplits));
 
     // interest amount
-    value = dynamic_cast<KMyMoneyEdit*>(haveWidget("interest-amount"));
+    value = dynamic_cast<AmountEdit*>(haveWidget("interest-amount"));
     if (!value)
       return;
+    value->setPrecision(MyMoneyMoney::denomToPrec(d->m_currency.smallestAccountFraction()));
     value->setValue(-d->subtotal(d->m_interestSplits));
 
     // total
@@ -750,7 +753,7 @@ void InvestTransactionEditor::loadEditWidgets()
     QStringList fields;
     fields << "shares" << "price" << "fee-amount" << "interest-amount";
     for (auto it_f = fields.constBegin(); it_f != fields.constEnd(); ++it_f) {
-      value = dynamic_cast<KMyMoneyEdit*>(haveWidget((*it_f)));
+      value = dynamic_cast<AmountEdit*>(haveWidget((*it_f)));
       if (!value)
         return;
       value->setText("");
@@ -776,6 +779,36 @@ bool InvestTransactionEditor::isComplete(QString& reason) const
 {
   Q_D(const InvestTransactionEditor);
   reason.clear();
+
+  auto postDate = dynamic_cast<KMyMoneyDateInput*>(d->m_editWidgets["postdate"]);
+  if (postDate) {
+    QDate accountOpeningDate = d->m_account.openingDate();
+    auto asset = dynamic_cast<KMyMoneyCategory*>(haveWidget("asset-account"));
+    if (asset && asset->isVisible()) {
+      if (!isMultiSelection() || !asset->currentText().isEmpty()) {
+        const auto assetId = asset->selectedItem();
+        if (!assetId.isEmpty()) {
+          try {
+            const auto acc = MyMoneyFile::instance()->account(assetId);
+            if (acc.openingDate() > accountOpeningDate)
+              accountOpeningDate = acc.openingDate();
+          } catch(MyMoneyException& e) {
+            qDebug() << "opening date check failed on account" << assetId << e.what();
+          }
+        }
+      }
+    }
+
+    if (postDate->date().isValid() && (postDate->date() < accountOpeningDate)) {
+      postDate->markAsBadDate(true, KMyMoneySettings::schemeColor(SchemeColor::Negative));
+      reason = i18n("Cannot enter transaction with postdate prior to account's opening date.");
+      postDate->setToolTip(reason);
+      return false;
+    }
+    postDate->markAsBadDate();
+    postDate->setToolTip(QString());
+  }
+
   return d->m_activity->isComplete(reason);
 }
 
@@ -790,7 +823,7 @@ void InvestTransactionEditor::slotUpdateSecurity(const QString& stockId)
   if (!currencyKnown) {
     d->m_currency.setTradingSymbol("???");
   } else {
-    auto sharesWidget = dynamic_cast<KMyMoneyEdit*>(haveWidget("shares"));
+    auto sharesWidget = dynamic_cast<AmountEdit*>(haveWidget("shares"));
     if (sharesWidget) {
       if (typeid(*(d->m_activity)) != typeid(Invest::Split(this)))
         sharesWidget->setPrecision(MyMoneyMoney::denomToPrec(d->m_security.smallestAccountFraction()));
@@ -824,10 +857,10 @@ MyMoneyMoney InvestTransactionEditor::totalAmount() const
   MyMoneyMoney amount;
 
   auto activityCombo = dynamic_cast<KMyMoneyActivityCombo*>(haveWidget("activity"));
-  auto sharesEdit = dynamic_cast<KMyMoneyEdit*>(haveWidget("shares"));
-  auto priceEdit = dynamic_cast<KMyMoneyEdit*>(haveWidget("price"));
-  auto feesEdit = dynamic_cast<KMyMoneyEdit*>(haveWidget("fee-amount"));
-  auto interestEdit = dynamic_cast<KMyMoneyEdit*>(haveWidget("interest-amount"));
+  auto sharesEdit = dynamic_cast<AmountEdit*>(haveWidget("shares"));
+  auto priceEdit = dynamic_cast<AmountEdit*>(haveWidget("price"));
+  auto feesEdit = dynamic_cast<AmountEdit*>(haveWidget("fee-amount"));
+  auto interestEdit = dynamic_cast<AmountEdit*>(haveWidget("interest-amount"));
 
   if (!activityCombo || !sharesEdit || !priceEdit ||
       !feesEdit || !interestEdit)
@@ -1056,7 +1089,7 @@ bool InvestTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyM
     foreach (const auto split, torig.splits()) {
       if (split.id() != sorig.id()) {
         auto cat = file->account(split.accountId());
-        if (cat.currencyId() != d->m_account.currencyId()) {
+        if (cat.currencyId() != t.commodity()) {
           if (cat.currencyId().isEmpty())
             cat.setCurrencyId(d->m_account.currencyId());
           if (!split.shares().isZero() && !split.value().isZero()) {
@@ -1094,7 +1127,7 @@ bool InvestTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyM
 
   // extract the splits from the original transaction, but only
   // if there is one because otherwise the currency is overridden
-  if (t.commodity().isEmpty()) {
+  if (torig.splitCount() != 0) {
     KMyMoneyUtils::dissectTransaction(torig, sorig,
                      assetAccountSplit,
                      feeSplits,
@@ -1114,7 +1147,7 @@ bool InvestTransactionEditor::createTransaction(MyMoneyTransaction& t, const MyM
   // keep the current activity object and create a new one
   // that can be destroyed later on
   auto activity = d->m_activity;
-  d->m_activity = 0;      // make sure we create a new one
+  d->m_activity = nullptr;      // make sure we create a new one
   d->activityFactory(activity->type());
 
   // if the activity is not set in the combo widget, we keep
