@@ -1,26 +1,21 @@
-/***************************************************************************
-                          kcurrencyeditdlg.cpp  -  description
-                             -------------------
-    begin                : Wed Mar 24 2004
-    copyright            : (C) 2000-2004 by Michael Edwardes
-    email                : mte@users.sourceforge.net
-                           Javier Campos Morales <javi_c@users.sourceforge.net>
-                           Felix Rodriguez <frodriguez@users.sourceforge.net>
-                           John C <thetacoturtle@users.sourceforge.net>
-                           Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           Kevin Tambascio <ktambascio@users.sourceforge.net>
-                           Alvaro Soliverez <asoliverez@gmail.com>
-                           (C) 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2004-2020  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2009-2010  Alvaro Soliverez <asoliverez@gmail.com>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "kcurrencyeditdlg.h"
 
@@ -46,13 +41,12 @@
 
 #include <KTreeWidgetSearchLineWidget>
 #include <KMessageBox>
+#include <KLocalizedString>
 
 // ----------------------------------------------------------------------------
 // Project Includes
 
 #include "ui_kcurrencyeditdlg.h"
-#include "ui_kcurrencyeditordlg.h"
-#include "ui_kavailablecurrencydlg.h"
 
 #include "mymoneyexception.h"
 #include "mymoneysecurity.h"
@@ -88,7 +82,7 @@ public:
   explicit KCurrencyEditDelegate(QObject *parent = 0);
 
 protected:
-  QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+  QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const final override;
 };
 
 KCurrencyEditDelegate::KCurrencyEditDelegate(QObject* parent): QStyledItemDelegate(parent)
@@ -108,10 +102,13 @@ class KCurrencyEditDlgPrivate
   Q_DECLARE_PUBLIC(KCurrencyEditDlg)
 
 public:
-  explicit KCurrencyEditDlgPrivate(KCurrencyEditDlg *qq)
-    : q_ptr(qq)
-    , ui(new Ui::KCurrencyEditDlg)
-    , m_inLoading(false)
+  explicit KCurrencyEditDlgPrivate(KCurrencyEditDlg *qq) :
+    q_ptr(qq),
+    ui(new Ui::KCurrencyEditDlg),
+    m_availableCurrencyDlg(nullptr),
+    m_currencyEditorDlg(nullptr),
+    m_searchWidget(nullptr),
+    m_inLoading(false)
   {
   }
 
@@ -161,7 +158,7 @@ public:
           MyMoneyFile::instance()->setBaseCurrency(cur);
           ft.commit();
         } catch (const MyMoneyException &e) {
-          KMessageBox::sorry(q, i18n("Cannot set %1 as base currency: %2", cur.name(), e.what()), i18n("Set base currency"));
+          KMessageBox::sorry(q, i18n("Cannot set %1 as base currency: %2", cur.name(), QString::fromLatin1(e.what())), i18n("Set base currency"));
         }
       }
     }
@@ -182,14 +179,56 @@ public:
           m_currentCurrency = currency;
           ft.commit();
         } catch (const MyMoneyException &e) {
-          KMessageBox::sorry(q, i18n("Cannot update currency. %1", e.what()), i18n("Update currency"));
+          KMessageBox::sorry(q, i18n("Cannot update currency. %1", QString::fromLatin1(e.what())), i18n("Update currency"));
         }
       }
     } catch (const MyMoneyException &e) {
-      KMessageBox::sorry(q, i18n("Cannot update currency. %1", e.what()), i18n("Update currency"));
+      KMessageBox::sorry(q, i18n("Cannot update currency. %1", QString::fromLatin1(e.what())), i18n("Update currency"));
     }
   }
 
+  /**
+   * Edit or create a currency
+   *
+   * @param currency reference to currency object
+   *
+   * @returns @c true in case the operation was successful @c false otherwise
+   * @note @a currency will be updated with the modified values
+   */
+  bool editCurrency(MyMoneySecurity& currency)
+  {
+    QScopedPointer<KCurrencyEditorDlg> currencyEditorDlg(new KCurrencyEditorDlg(currency, q_ptr));
+    bool rc = true;
+    do {
+      if (currencyEditorDlg->exec() != QDialog::Rejected) {
+        auto file = MyMoneyFile::instance();
+        MyMoneyFileTransaction ft;
+        try {
+          if (currency.id().isEmpty()) {
+            file->addCurrency(currencyEditorDlg->currency());
+          } else {
+            file->modifyCurrency(currencyEditorDlg->currency());
+          }
+          ft.commit();
+          // if the modification worked, then we copy the data
+          // to inform caller
+          currency = currencyEditorDlg->currency();
+
+        } catch (const MyMoneyException &e) {
+          if (currency.id().isEmpty()) {
+            KMessageBox::sorry(q_ptr, i18n("Cannot create new currency. %1", QString::fromLatin1(e.what())), i18n("New currency"));
+          } else {
+            KMessageBox::sorry(q_ptr, i18n("Cannot modify currency. %1", QString::fromLatin1(e.what())), i18n("Edit currency"));
+          }
+        }
+      } else {
+        rc = false;   // aborted by user
+      }
+    } while(false);
+
+    return rc;
+  }
+
   KCurrencyEditDlg      *q_ptr;
   Ui::KCurrencyEditDlg  *ui;
 
@@ -215,6 +254,7 @@ KCurrencyEditDlg::KCurrencyEditDlg(QWidget *parent) :
   d->ui->verticalLayout->insertWidget(0, d->m_searchWidget);
   d->ui->m_currencyList->setItemDelegate(new KCurrencyEditDelegate(d->ui->m_currencyList));
   d->ui->m_closeButton->setIcon(Icons::get(Icon::DialogClose));
+  d->ui->m_newCurrencyButton->setIcon(Icons::get(Icon::DocumentNew));
   d->ui->m_editCurrencyButton->setIcon(Icons::get(Icon::DocumentEdit));
   d->ui->m_selectBaseCurrencyButton->setIcon(Icons::get(Icon::KMyMoney));
 
@@ -225,6 +265,7 @@ KCurrencyEditDlg::KCurrencyEditDlg(QWidget *parent) :
 
   connect(d->ui->m_selectBaseCurrencyButton, &QAbstractButton::clicked, this, &KCurrencyEditDlg::slotSelectBaseCurrency);
   connect(d->ui->m_addCurrencyButton, &QAbstractButton::clicked, this, &KCurrencyEditDlg::slotAddCurrency);
+  connect(d->ui->m_newCurrencyButton, &QAbstractButton::clicked, this, &KCurrencyEditDlg::slotNewCurrency);
   connect(d->ui->m_removeCurrencyButton, &QAbstractButton::clicked, this, &KCurrencyEditDlg::slotRemoveCurrency);
   connect(d->ui->m_editCurrencyButton, &QAbstractButton::clicked, this, &KCurrencyEditDlg::slotEditCurrency);
   connect(d->ui->m_removeUnusedCurrencyButton, &QAbstractButton::clicked, this, &KCurrencyEditDlg::slotRemoveUnusedCurrency);
@@ -298,7 +339,7 @@ void KCurrencyEditDlg::slotLoadCurrencies()
   try {
     baseCurrency = MyMoneyFile::instance()->baseCurrency().id();
   } catch (const MyMoneyException &e) {
-    qDebug("%s", qPrintable(e.what()));
+    qDebug("%s", e.what());
   }
 
   // construct a transparent 16x16 pixmap
@@ -365,23 +406,18 @@ void KCurrencyEditDlg::slotUpdateCurrency(QTreeWidgetItem* citem, QTreeWidgetIte
 {
   Q_D(KCurrencyEditDlg);
   Q_UNUSED(pitem)
-  //if there is no current item selected, exit
+  // if there is no current item selected, exit
   if (!d->ui->m_currencyList->currentItem() || citem != d->ui->m_currencyList->currentItem())
     return;
 
-  //verify that the stored currency id is not empty and the edited fields are not empty either
-  if (!d->m_currentCurrency.id().isEmpty()
-      && !d->ui->m_currencyList->currentItem()->text(2).isEmpty()
-      && !d->ui->m_currencyList->currentItem()->text(0).isEmpty()) {
-    //check that either the name or the id have changed
-    if (d->ui->m_currencyList->currentItem()->text(2) != d->m_currentCurrency.tradingSymbol()
-        || d->ui->m_currencyList->currentItem()->text(0) != d->m_currentCurrency.name()) {
-      //update the name and the id
-      d->m_currentCurrency.setName(d->ui->m_currencyList->currentItem()->text(0));
-      d->m_currentCurrency.setTradingSymbol(d->ui->m_currencyList->currentItem()->text(2));
+  const auto newName = d->ui->m_currencyList->currentItem()->text(0);
+  const auto newSymbol = d->ui->m_currencyList->currentItem()->text(2);
 
-      d->updateCurrency(d->m_currentCurrency.id(), d->m_currentCurrency.name(), d->m_currentCurrency.tradingSymbol());
-    }
+  // verify that the stored currency id is not empty and the edited fields are not empty either
+  if (!d->m_currentCurrency.id().isEmpty()
+      && !newSymbol.isEmpty()
+      && !newName.isEmpty()) {
+    d->updateCurrency(d->m_currentCurrency.id(), newName, newSymbol);
   }
 }
 
@@ -476,7 +512,7 @@ void KCurrencyEditDlg::slotShowCurrencyMenu(const QPoint& p)
     };
 
     const QVector<actionInfo> actionInfos {
-      {eMenu::Action::NewCurrency,      &KCurrencyEditDlg::slotNewCurrency,     i18n("New currency"),            Icon::ListAdd,     true},
+      {eMenu::Action::NewCurrency,      &KCurrencyEditDlg::slotNewCurrency,     i18n("New currency"),            Icon::DocumentNew, true},
       {eMenu::Action::RenameCurrency,   &KCurrencyEditDlg::slotRenameCurrency,  i18n("Rename currency"),         Icon::EditRename,  cond1},
       {eMenu::Action::DeleteCurrency,   &KCurrencyEditDlg::slotDeleteCurrency,  i18n("Delete currency"),         Icon::EditDelete,  cond2},
       {eMenu::Action::SetBaseCurrency,  &KCurrencyEditDlg::slotSetBaseCurrency, i18n("Select as base currency"), Icon::KMyMoney,    cond3}
@@ -516,12 +552,37 @@ void KCurrencyEditDlg::slotAddCurrency()
     auto file = MyMoneyFile::instance();
     QMap<MyMoneySecurity, MyMoneyPrice> ancientCurrencies = file->ancientCurrencies();
     MyMoneyFileTransaction ft;
-    QList<QTreeWidgetItem *> currencyRows = d->m_availableCurrencyDlg->ui->m_currencyList->selectedItems(); // get selected currencies from new dialog
+    QList<QTreeWidgetItem *> currencyRows = d->m_availableCurrencyDlg->selectedItems(); // get selected currencies from new dialog
     foreach (auto currencyRow, currencyRows) {
       MyMoneySecurity currency = currencyRow->data(0, Qt::UserRole).value<MyMoneySecurity>();
       file->addCurrency(currency);
-      if (ancientCurrencies.value(currency, MyMoneyPrice()) != MyMoneyPrice()) // if ancient currency is added...
-        file->addPrice(ancientCurrencies[currency]);                           // ...we want to add last known exchange rate as well
+      if (ancientCurrencies.value(currency, MyMoneyPrice()) != MyMoneyPrice()) { // if ancient currency is added...
+        file->addPrice(ancientCurrencies[currency]);                             // ...we want to add last known exchange rate as well
+      } else {
+        // check if a new currency is added and the old one is already on file.
+        // in that case, we want to add the last know exchange rate as well
+        for (const auto &price : qAsConst(ancientCurrencies)) {
+          QString ancientCurrencyId;
+          if (price.from() == currency.id()) {
+            ancientCurrencyId = price.to();
+          } else if (price.to() == currency.id()) {
+            ancientCurrencyId = price.from();
+          }
+          if (!ancientCurrencyId.isEmpty()) {
+            // we found a replacement record, so we look for the
+            // older variant
+            try {
+              const auto ancientCurrency = file->currency(ancientCurrencyId);
+              if (!ancientCurrency.id().isEmpty()) {
+                file->addPrice(ancientCurrencies[ancientCurrency]);
+              }
+            } catch (MyMoneyException& e) {
+              // nothing to do because ancient currency is not on file
+            }
+            break;
+          }
+        }
+      }
     }
     ft.commit();
     d->ui->m_removeUnusedCurrencyButton->setDisabled(file->currencyList().count() <= 1);
@@ -544,36 +605,23 @@ void KCurrencyEditDlg::slotRemoveUnusedCurrency()
 void KCurrencyEditDlg::slotEditCurrency()
 {
   Q_D(KCurrencyEditDlg);
-  MyMoneySecurity currency = d->ui->m_currencyList->currentItem()->data(0, Qt::UserRole).value<MyMoneySecurity>();
-  d->m_currencyEditorDlg = new KCurrencyEditorDlg(currency);                                   // create new dialog for editing currency
-  if (d->m_currencyEditorDlg->exec() != QDialog::Rejected) {
-    auto file = MyMoneyFile::instance();
-    MyMoneyFileTransaction ft;
-    currency.setPricePrecision(d->m_currencyEditorDlg->ui->m_pricePrecision->value());
-    try {
-      file->modifyCurrency(currency);
-      ft.commit();
-    } catch (const MyMoneyException &e) {
-      qDebug("%s", qPrintable(e.what()));
-    }
-  }
-  delete d->m_currencyEditorDlg;
+  auto currency = d->ui->m_currencyList->currentItem()->data(0, Qt::UserRole).value<MyMoneySecurity>();
+  d->editCurrency(currency);
+
+  // update the model data
+  const auto item = d->ui->m_currencyList->currentItem();
+  item->setData(0, Qt::UserRole, QVariant::fromValue(currency));
+  item->setText(0, currency.name());
+  item->setText(1, currency.id());
+  item->setText(2, currency.tradingSymbol());
 }
 
 void KCurrencyEditDlg::slotNewCurrency()
 {
-  QString sid = QInputDialog::getText(0, i18n("New currency"), i18n("Enter ISO 4217 code for the new currency"));
-  if (!sid.isEmpty()) {
-    QString id(sid);
-    MyMoneySecurity currency(id, i18n("New currency"));
-    MyMoneyFileTransaction ft;
-    try {
-      MyMoneyFile::instance()->addCurrency(currency);
-      ft.commit();
-    } catch (const MyMoneyException &e) {
-      KMessageBox::sorry(this, i18n("Cannot create new currency. %1", e.what()), i18n("New currency"));
-    }
-    slotSelectCurrency(id);
+  Q_D(KCurrencyEditDlg);
+  MyMoneySecurity currency;
+  if (d->editCurrency(currency)) {
+    slotSelectCurrency(currency.id());
   }
 }
 
@@ -582,7 +630,7 @@ void KCurrencyEditDlg::slotRenameCurrency()
   Q_D(KCurrencyEditDlg);
   QTreeWidgetItemIterator it_l(d->ui->m_currencyList, QTreeWidgetItemIterator::Selected);
   QTreeWidgetItem* it_v;
-  if ((it_v = *it_l) != 0) {
+  if ((it_v = *it_l) != nullptr) {
     d->ui->m_currencyList->editItem(it_v, 0);
   }
 }
@@ -596,7 +644,7 @@ void KCurrencyEditDlg::slotDeleteCurrency()
       MyMoneyFile::instance()->removeCurrency(d->m_currentCurrency);
       ft.commit();
     } catch (const MyMoneyException &e) {
-      KMessageBox::sorry(this, i18n("Cannot delete currency %1. %2", d->m_currentCurrency.name(), e.what()), i18n("Delete currency"));
+      KMessageBox::sorry(this, i18n("Cannot delete currency %1. %2", d->m_currentCurrency.name(), QString::fromLatin1(e.what())), i18n("Delete currency"));
     }
   }
 }
@@ -611,7 +659,7 @@ void KCurrencyEditDlg::slotSetBaseCurrency()
         MyMoneyFile::instance()->setBaseCurrency(d->m_currentCurrency);
         ft.commit();
       } catch (const MyMoneyException &e) {
-        KMessageBox::sorry(this, i18n("Cannot set %1 as base currency: %2", d->m_currentCurrency.name(), e.what()), i18n("Set base currency"));
+        KMessageBox::sorry(this, i18n("Cannot set %1 as base currency: %2", d->m_currentCurrency.name(), QString::fromLatin1(e.what())), i18n("Set base currency"));
       }
     }
   }
