@@ -111,7 +111,7 @@ KNewBankDlg::KNewBankDlg(MyMoneyInstitution& institution, QWidget *parent) :
   connect(d->ui->iconButton, &QToolButton::pressed, this,
           [=] {
             QUrl url;
-            url.setUrl(QString::fromLatin1("https://%1/").arg(d->ui->urlEdit->text()));
+            url.setUrl(QString::fromLatin1("https://%1").arg(d->ui->urlEdit->text()));
             QDesktopServices::openUrl(url);
           });
 
@@ -187,7 +187,7 @@ void KNewBankDlg::slotUrlChanged(const QString& newUrl)
   QRegularExpressionMatch matcher = protocol.match(newUrl);
   if (matcher.hasMatch()) {
     d->ui->urlEdit->setText(matcher.captured(QStringLiteral("url")));
-    d->ui->messageWidget->setText(QLatin1String("The protocol part has been removed by KMyMoney because it is fixed to https."));
+    d->ui->messageWidget->setText(i18nc("@info:usagetip", "The protocol part has been removed by KMyMoney because it is fixed to https for security reasons."));
     d->ui->messageWidget->setMessageType(KMessageWidget::Information);
     d->ui->messageWidget->animatedShow();
   }
