@@ -1,19 +1,20 @@
-/***************************************************************************
-                             ksettingsgeneral.cpp
-                             --------------------
-    copyright            : (C) 2005 by Thomas Baumgart
-    email                : ipwizard@users.sourceforge.net
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2005-2008  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "ksettingsgeneral.h"
 
@@ -44,7 +45,8 @@ class KSettingsGeneralPrivate
 
 public:
   KSettingsGeneralPrivate() :
-    ui(new Ui::KSettingsGeneral)
+    ui(new Ui::KSettingsGeneral),
+    initialHideZeroBalanceEquities(false)
   {
   }
 
@@ -66,7 +68,7 @@ KSettingsGeneral::KSettingsGeneral(QWidget* parent) :
   // hide the internally used date field
   d->ui->kcfg_StartDate->hide();
 
-  // setup connections, so that the sort optios get loaded once the edit fields are filled
+  // setup connections, so that the sort options get loaded once the edit fields are filled
   connect(d->ui->kcfg_StartDate, &QDateTimeEdit::dateChanged, this, &KSettingsGeneral::slotLoadStartDate);
 
   // setup connections, so that changes by the user are forwarded to the (hidden) edit fields
@@ -136,8 +138,8 @@ void KSettingsGeneral::slotUpdateEquitiesVisibility()
         accountsModel->slotObjectRemoved(eMyMoney::File::Object::Account, account.id());     // remove item from accounts' page
         institutionsModel->slotObjectRemoved(eMyMoney::File::Object::Account, account.id()); // remove item from institutions' page
       } else {
-        accountsModel->slotObjectAdded(eMyMoney::File::Object::Account, dynamic_cast<const MyMoneyObject* const>(&account));     // add item to accounts' page
-        institutionsModel->slotObjectAdded(eMyMoney::File::Object::Account, dynamic_cast<const MyMoneyObject* const>(&account)); // add item to institutions' page
+        accountsModel->slotObjectAdded(eMyMoney::File::Object::Account, account.id());     // add item to accounts' page
+        institutionsModel->slotObjectAdded(eMyMoney::File::Object::Account, account.id()); // add item to institutions' page
       }
     }
   }
