@@ -1,19 +1,20 @@
-/***************************************************************************
-                             ksettingsschedules.cpp
-                             --------------------
-    copyright            : (C) 2005 by Thomas Baumgart
-    email                : ipwizard@users.sourceforge.net
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2005-2010  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017       Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include <config-kmymoney.h>
 
@@ -26,7 +27,7 @@
 // KDE Includes
 
 #include <KLocalizedString>
-#ifdef KF5Holidays_FOUND
+#ifdef ENABLE_HOLIDAYS
 #include <KHolidays/Holiday>
 #include <KHolidays/HolidayRegion>
 using namespace KHolidays;
@@ -85,14 +86,15 @@ void KSettingsSchedules::loadList()
 {
   Q_D(KSettingsSchedules);
   QStringList regions;
-#ifdef KF5Holidays_FOUND
+#ifdef ENABLE_HOLIDAYS
   QStringList regionCodes = HolidayRegion::regionCodes();
 
   foreach (const QString &regionCode, regionCodes) {
-    QString regionName = HolidayRegion::name(regionCode);
-    QLocale langLocale(HolidayRegion::languageCode(regionCode));
-    QString languageName = QLocale().languageToString(langLocale.language());
-    QString region = languageName.isEmpty() ? regionName : i18nc("Holiday region (region language)", "%1 (%2)", regionName, languageName);
+    const auto regionName( HolidayRegion::name(regionCode));
+    const QLocale langLocale(HolidayRegion::languageCode(regionCode));
+    const auto languageName = QLocale().languageToString(langLocale.language());
+    const auto description = HolidayRegion::description(regionCode);
+    const QString region = !description.isEmpty() ? description : i18nc("Holiday region (region language)", "Holidays for %1 (%2)", regionName, languageName);
     d->m_regionMap[region] = regionCode;
     regions << region;
   }
