@@ -51,7 +51,7 @@
 #include "mymoneyexception.h"
 #include "kmymoneycategory.h"
 #include "kmymoneymvccombo.h"
-#include "kmymoneyedit.h"
+#include "amountedit.h"
 #include "kmymoneylineedit.h"
 #include "mymoneyfile.h"
 #include "mymoneyprice.h"
@@ -153,7 +153,7 @@ void TransactionEditor::setupPrecision()
   for (it_w = widgets.constBegin(); it_w != widgets.constEnd(); ++it_w) {
     QWidget * w;
     if ((w = haveWidget(*it_w)) != 0) {
-      if (auto precisionWidget = dynamic_cast<KMyMoneyEdit*>(w))
+      if (auto precisionWidget = dynamic_cast<AmountEdit*>(w))
         precisionWidget->setPrecision(prec);
     }
   }
@@ -187,7 +187,7 @@ void TransactionEditor::setup(QWidgetList& tabOrderWidgets, const MyMoneyAccount
       ++it_w;
     } else {
       // before we remove the widget, we make sure it's not a part of a known one.
-      // these could be a direct child in case of KMyMoneyDateInput and KMyMoneyEdit
+      // these could be a direct child in case of KMyMoneyDateInput and AmountEdit
       // where we store the pointer to the surrounding frame in editWidgets
       // or the parent is called "KMyMoneyCategoryFrame"
       if (*it_w) {
@@ -269,15 +269,15 @@ bool TransactionEditor::eventFilter(QObject* o, QEvent* e)
       && (e->type() == QEvent::KeyPress)
       && numberWiget && d->m_editWidgets.values().contains(numberWiget)) {
     auto k = dynamic_cast<QKeyEvent*>(e);
-    if ((k && (k->modifiers() & Qt::KeyboardModifierMask)) == 0
-        || (k && (k->modifiers() & Qt::KeypadModifier)) != 0) {
+    if (k && (((k->modifiers() & Qt::KeyboardModifierMask) == 0)
+           || ((k->modifiers() & Qt::KeypadModifier) != 0))) {
       bool isFinal = false;
       QList<const QWidget*>::const_iterator it_w;
       switch (k->key()) {
         case Qt::Key_Return:
         case Qt::Key_Enter:
           // we check, if the object is one of the m_finalEditWidgets and if it's
-          // a KMyMoneyEdit object that the value is not 0. If any of that is the
+          // a AmountEdit object that the value is not 0. If any of that is the
           // case, it's the final object. In other cases, we convert the enter
           // key into a TAB key to move between the fields. Of course, we only need
           // to do this as long as the appropriate option is set. In all other cases,
@@ -285,7 +285,7 @@ bool TransactionEditor::eventFilter(QObject* o, QEvent* e)
           if (KMyMoneySettings::enterMovesBetweenFields()) {
             for (it_w = d->m_finalEditWidgets.constBegin(); !isFinal && it_w != d->m_finalEditWidgets.constEnd(); ++it_w) {
               if (*it_w == o) {
-                if (auto widget = dynamic_cast<const KMyMoneyEdit*>(*it_w)) {
+                if (auto widget = dynamic_cast<const AmountEdit*>(*it_w)) {
                   isFinal = !(widget->value().isZero());
                 } else
                   isFinal = true;
@@ -680,6 +680,18 @@ bool TransactionEditor::enterTransactions(QString& newId, bool askForSchedule, b
             maxCreditAbsolute[acc.id()] = balance < MyMoneyMoney(acc.value("maxCreditAbsolute"));
             maxCreditEarly[acc.id()] = false;
           }
+
+        // and adjust opening date of invest accounts
+          if (acc.isInvest()) {
+            if (acc.openingDate() > t.postDate()) {
+              try {
+                acc.setOpeningDate(t.postDate());
+                file->modifyAccount(acc);
+              } catch(MyMoneyException& ) {
+                qDebug() << "Unable to modify opening date for invest account" << acc.name() << acc.id();
+              }
+            }
+          }
         }
 
         if (transaction.id().isEmpty()) {
@@ -690,7 +702,7 @@ bool TransactionEditor::enterTransactions(QString& newId, bool askForSchedule, b
                                  i18n("Accepts the entered data and stores it"),
                                  i18n("Use this to enter the transaction into the ledger."));
             KGuiItem scheduleButton(i18n("&Schedule"),
-                                    Icons::get(Icon::AppointmentNew),
+                                    Icons::get(Icon::NewSchedule),
                                     i18n("Accepts the entered data and stores it as schedule"),
                                     i18n("Use this to schedule the transaction for later entry into the ledger."));
 
