@@ -3,6 +3,8 @@
                              -------------------
     begin                : Sun Jun 25 2017
     copyright            : (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+                           (C) 2020 by Dawid Wróbel <me@dawidwrobel.com>
+
 
 ***************************************************************************/
 
@@ -31,66 +33,68 @@ class QIcon;
 
 namespace Icons {
 
-enum class Icon { SVNUpdate, Merge, Reconcile, Split, Tip, Fork,
-                  FileArchiver, AccessoriesCalculator,
+enum class IconSet { Common, Oxygen, Tango, Breeze };
+
+enum class Icon { OpenDatabase, Merge, Reconcile, Split, Tip, PerformanceTest,
+                  Calculator,
                   UserProperties, DocumentProperties,
                   ZoomIn, ZoomOut,
-                  MediaPlaybackPause, MediaSeekForward,
-                  MediaSkipForward,
+                  Pause, SeekForward,
+                  SkipForward,
                   HideReconciled, HideCategories,
-                  ViewHome, ViewInstitutions,
-                  ViewAccounts, ViewCategories,
-                  ViewSchedules, ViewTags,
-                  ViewPayees, ViewLedgers,
-                  ViewInvestment, ViewReports,
-                  ViewBudgets, ViewForecast,
-                  ViewOutbox, ViewFilter,
-                  ViewLoan, ViewStock,
-                  ViewChecking,
-                  ViewSaving,
-                  ViewLoanAsset, ViewCreditCard,
-                  ViewCash, ViewEquity,
-                  ViewIncome, ViewExpense,
-                  ViewAsset, ViewLiability,
-                  ViewUpcominEvents, ViewCalendarDay,
-                  ViewFinancialList, ViewBankAccount,
-                  ViewCurrencyList, ViewFinancialCategories,
-                  ViewFinancialTransfer, ViewBank,
-                  ViewTimeScheduleCalculus, ViewCalendar,
-                  ViewTransactionDetail, ViewClose,
+                  Home, Institution, Institutions,
+                  Accounts,
+                  Schedule, Tags,
+                  Payees,
+                  Investment, Investments, Reports,
+                  Budget, Forecast,
+                  OnlineJobOutbox, Filter,
+                  Loan, Stock,
+                  Checking,
+                  Savings,
+                  LoanAsset, CreditCard,
+                  Cash, Equity,
+                  Income, Expense,
+                  Asset, Liability,
+                  UpcomingEvents, CalendarDay,
+                  Ledger, BankAccount,
+                  Currencies, FinancialCategories,
+                  Transaction, Bank,
+                  Calendar,
+                  TransactionDetails, Close,
                   DialogOK, DialogClose, DialogCancel,
                   DialogOKApply, DialogError, DialogWarning,
                   DialogInformation,
                   ListExpand, ListCollapse,
                   ListAdd, ListAddUser, ListRemoveUser,
                   ListAddTag, ListRemoveTag,
-                  GoJump, KeyEnter, Download, TagRename,
+                  GoTo, KeyEnter, Download, TagRename,
                   EditDelete, EditCopy, EditRename,
-                  EditFind, EditUndo, EditClear,
+                  Find, EditUndo, EditClear,
                   DocumentEdit,
                   DocumentNew, DocumentSave,
                   DocumentClose, DocumentOpen,
                   DocumentImport, DocumentExport,
                   OfficeChartLine,
                   MailMessageNew, MailMessage, MailReceive,
-                  NewsSubscribe, NewsUnsubscribe,
-                  AppointmentNew, KMyMoney,
+                  MapOnlineAccount, UnmapOnlineAccount,
+                  NewSchedule, KMyMoney,
                   PayeeRename, PayeeMerge,
-                  PathEnter, PathSkip, Configure,
-                  FlagGreen, AccountClosed, Unknown,
-                  Spreadsheet, Refresh, SystemRun,
+                  Configure,
+                  Reconciled, AccountClosed, Unknown,
+                  Report, Refresh, PreferencesGeneral,
                   SortAscending, SortDescending,
                   ArrowUp, ArrowDown, ArrowRight, ArrowLeft,
-                  TaskAttention, TaskComplete,
+                  Warning, TaskComplete,
                   TaskReject, TaskAccepted, TaskOngoing,
-                  HelpContents, Folder, InvestApplet,
-                  PreferencesFont, PreferencesColor, PreferencesIcon,
-                  PreferencesNetwork, NetworkDisconect, Kgpg,
-                  Empty, EditFindTransaction,
+                  Help, Folder,
+                  PreferencesFonts, PreferencesColors, PreferencesIcons,
+                  PreferencesNetwork, PreferencesPlugins,
+                  Empty,
                   InstitutionNew, InstitutionEdit, InstitutionDelete,
                   AccountNew, AccountEdit, AccountDelete,
                   AccountClose, AccountReopen,
-                  AccountUpdateMenu, AccountUpdate, AccountUpdateAll,
+                  AccountUpdate, AccountUpdateAll,
                   AccountCreditTransfer, AccountFinishReconciliation,
                   CategoryNew, CategoryEdit, CategoryDelete,
                   TransactionNew, TransactionEdit,
@@ -98,10 +102,11 @@ enum class Icon { SVNUpdate, Merge, Reconcile, Split, Tip, Fork,
                   InvestmentNew, InvestmentEdit,
                   InvestmentDelete, InvestmentOnlinePrice,
                   BudgetNew, BudgetRename, BudgetDelete, BudgetCopy,
-                  PriceUpdate, ToolUpdatePrices
+                  PriceUpdate, InvestmentOnlinePriceAll, Reverse, Visibility, NoVisibility,
+                  SelectAll
                 };
 
-KMM_ICONS_EXPORT void setIconThemeNames(const QString &_themeName);
+KMM_ICONS_EXPORT void setUpMappings(const QString & themeName);
 KMM_ICONS_EXPORT QIcon get(Icons::Icon icon);
 
 
