@@ -2,7 +2,7 @@
                           kmymoney.h
                              -------------------
     copyright            : (C) 2000-2001 by Michael Edwardes <mte@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+                           (C) 2017, 2018 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
 
 ***************************************************************************/
 
@@ -46,6 +46,7 @@
 #include "mymoneysplit.h"
 #include "mymoneytransaction.h"
 #include "mymoneyenums.h"
+#include "viewenums.h"
 
 class QResizeEvent;
 class MyMoneyObject;
@@ -59,9 +60,12 @@ class MyMoneySplit;
 class MyMoneyTransaction;
 class WebConnect;
 class creditTransfer;
+class IMyMoneyOperationsFormat;
 
 template <class T> class onlineJobTyped;
+typedef  void (*KMyMoneyAppCallback)(int, int, const QString &);
 
+namespace eKMyMoney { enum class FileAction; }
 namespace eDialogs { enum class ScheduleResultCode; }
 namespace eMenu { enum class Action;
                   enum class Menu; }
@@ -93,11 +97,6 @@ class KMyMoneyApp : public KXmlGuiWindow, public IMyMoneyProcessingCalendar
   Q_OBJECT
 
 private Q_SLOTS:
-  /**
-    * Keep track of objects that are destroyed by external events
-    */
-  void slotObjectDestroyed(QObject* o);
-
   /**
     * Add a context menu to the list used by KMessageBox::informationList to display the consistency check results.
     */
@@ -109,8 +108,6 @@ private Q_SLOTS:
   void slotShowContextMenuForConsistencyCheck(const QPoint &);
 
 protected Q_SLOTS:
-  void slotFileSaveAsFilterChanged(const QString& filter);
-
   /**
     * This slot is intended to be used as part of auto saving. This is used when the
     * QTimer emits the timeout signal and simply checks that the file is dirty (has
@@ -127,11 +124,6 @@ protected Q_SLOTS:
     */
   void slotEnableMessages();
 
-  /**
-    * Called when the user asks for file information.
-    */
-  void slotFileFileInfo();
-
   /**
     * Called to run performance test.
     */
@@ -143,6 +135,11 @@ protected Q_SLOTS:
   void slotGenerateSql();
 
 #ifdef KMM_DEBUG
+  /**
+    * Called when the user asks for file information.
+    */
+  void slotFileFileInfo();
+
   /**
     * Debugging only: turn on/off traces
     */
@@ -210,16 +207,7 @@ protected Q_SLOTS:
 
   void slotShowNextView();
 
-  /**
-    * Brings up a dialog to let the user search for specific transaction(s).  It then
-    * opens a results window to display those transactions.
-    */
-  void slotFindTransaction();
-
-  /**
-    * Destroys a possibly open the search dialog
-    */
-  void slotCloseSearchDialog();
+  void slotViewSelected(View view);
 
   /**
     * Calls the print logic for the current view
@@ -255,16 +243,10 @@ protected Q_SLOTS:
     */
   void slotScheduleNew(const MyMoneyTransaction& t, eMyMoney::Schedule::Occurrence occurrence = eMyMoney::Schedule::Occurrence::Monthly);
 
-  void slotAccountMapOnline();
-  void slotAccountUnmapOnline();
-  void slotAccountUpdateOnline();
-  void slotAccountUpdateOnlineAll();
-
-  void slotManageGpgKeys();
-  void slotKeySelected(int idx);
-
   void slotStatusProgressDone();
 
+  void slotCheckSchedules();
+
 public:
   /**
     * This method checks if there is at least one asset or liability account
@@ -284,7 +266,7 @@ public:
   QUrl lastOpenedURL();
 
   /**
-    * construtor of KMyMoneyApp, calls all init functions to create the application.
+    * constructor of KMyMoneyApp, calls all init functions to create the application.
     */
   explicit KMyMoneyApp(QWidget* parent = 0);
 
@@ -305,16 +287,6 @@ public:
     */
   bool isImportableFile(const QUrl &url);
 
-  /**
-    * This method is used to update the caption of the application window.
-    * It sets the caption to "filename [modified] - KMyMoney".
-    *
-    * @param skipActions if true, the actions will not be updated. This
-    *                    is usually onyl required by some early calls when
-    *                    these widgets are not yet created (the default is false).
-    */
-  void updateCaption(bool skipActions = false);
-
   /**
     * This method returns a list of all 'other' dcop registered kmymoney processes.
     * It's a subset of the return of DCOPclient()->registeredApplications().
@@ -339,6 +311,11 @@ public:
   void createAccount(MyMoneyAccount& newAccount, MyMoneyAccount& parentAccount, MyMoneyAccount& brokerageAccount, MyMoneyMoney openingBal);
 
   QString filename() const;
+  QUrl filenameURL() const;
+  void writeFilenameURL(const QUrl &url);
+
+  void addToRecentFiles(const QUrl &url);
+  QTimer* autosaveTimer();
 
   /**
     * Checks if the file with the @a url already exists. If so,
@@ -353,6 +330,28 @@ public:
    */
   WebConnect* webConnect() const;
 
+  /**
+   * Call this to find out if the currently open file is a sql database
+   *
+   * @retval true file is database
+   * @retval false file is serial
+   */
+  bool isDatabase();
+
+  /**
+    * Call this to find out if the currently open file is native KMM
+    *
+    * @retval true file is native
+    * @retval false file is foreign
+    */
+  bool isNativeFile();
+
+  bool fileOpen() const;
+
+  KMyMoneyAppCallback progressCallback();
+
+  void consistencyCheck(bool alwaysDisplayResult);
+
 protected:
   /** save general Options like all bar positions and status as well as the geometry and the recent file list to the configuration
    * file
@@ -386,10 +385,13 @@ protected:
   void initDynamicMenus();
 
   /**
-   * sets up the statusbar for the main window by initialzing a statuslabel.
+   * sets up the statusbar for the main window by initializing a statuslabel.
    */
   void initStatusBar();
 
+  /** sets up the application icons */
+  void initIcons();
+
   /** queryClose is called by KMainWindow on each closeEvent of a window. Against the
    * default implementation (only returns true), this calls saveModified() on the document object to ask if the document shall
    * be saved if Modified; on cancel the closeEvent is rejected.
@@ -397,11 +399,11 @@ protected:
    * @see KMainWindow#queryClose
    * @see QWidget#closeEvent
    */
-  virtual bool queryClose();
+  bool queryClose() final override;
 
-  void slotCheckSchedules();
-
-  virtual void resizeEvent(QResizeEvent*);
+#ifdef KMM_DEBUG
+  void resizeEvent(QResizeEvent*) final override;
+#endif
 
   void createSchedule(MyMoneySchedule newSchedule, MyMoneyAccount& newAccount);
 
@@ -414,58 +416,7 @@ public Q_SLOTS:
 
   void slotFileInfoDialog();
 
-  /** */
-  void slotFileNew();
-
-  /** open a file and load it into the document*/
-  void slotFileOpen();
-
-  /** opens a file from the recent files menu */
-
-  void slotFileOpenRecent(const QUrl &url);
-
-  /** open a SQL database */
-  void slotOpenDatabase();
-
-  /**
-    * saves the current document. If it has no name yet, the user
-    * will be queried for it.
-    *
-    * @retval false save operation failed
-    * @retval true save operation was successful
-    */
-  bool slotFileSave();
-
-  /**
-    * ask the user for the filename and save the current document
-    *
-    * @retval false save operation failed
-    * @retval true save operation was successful
-    */
-  bool slotFileSaveAs();
-
-  /**
-   * ask the user to select a database and save the current document
-   *
-   * @retval false save operation failed
-   * @retval true save operation was successful
-   */
-  bool saveAsDatabase();
-  void slotSaveAsDatabase();
-
-  /** asks for saving if the file is modified, then closes the actual file and window */
-  void slotFileCloseWindow();
-
-  /** asks for saving if the file is modified, then closes the actual file */
-  void slotFileClose();
-
-  /**
-    * closes all open windows by calling close() on each memberList item
-    * until the list is empty, then quits the application.
-    * If queryClose() returns false because the user canceled the
-    * saveModified() dialog, the closing breaks.
-    */
-  void slotFileQuit();
+  bool isFileOpenedInAnotherInstance(const QUrl &url);
 
   void slotFileConsistencyCheck();
 
@@ -529,8 +480,6 @@ public Q_SLOTS:
     */
   void slotEquityPriceUpdate();
 
-  void slotOnlineAccountRequested(const MyMoneyAccount& acc, eMenu::Action action);  
-
   /**
     * This slot reparents account @p src to be a child of account @p dest
     *
@@ -574,22 +523,13 @@ public Q_SLOTS:
     */
   void slotToolsStartKCalc();
 
-  void slotResetSelections();
-
-  void slotSelectAccount(const MyMoneyObject& account);
-
   /**
     * Brings up the new account wizard and saves the information.
     */
   void slotAccountNew(MyMoneyAccount&);
 
-  /**
-    * This method updates all KAction items to the current state.
-    */
-  void slotUpdateActions();
-
   void webConnect(const QString& sourceUrl, const QByteArray &asn_id);
-  void webConnect(const QUrl url) { webConnect(url.path(), QByteArray()); }
+  void webConnectUrl(const QUrl url);
 
 private:
   /**
@@ -615,15 +555,7 @@ private:
   /**
     * Re-implemented from IMyMoneyProcessingCalendar
     */
-  bool isProcessingDate(const QDate& date) const;
-
-  /**
-    * Depending on the setting of AutoSaveOnQuit, this method
-    * asks the user to save the file or not.
-    *
-    * @returns see return values of KMessageBox::warningYesNoCancel()
-    */
-  int askSaveOnClose();
+  bool isProcessingDate(const QDate& date) const final override;
 
 Q_SIGNALS:
   /**
@@ -640,20 +572,18 @@ Q_SIGNALS:
     */
   void transactionsSelected(const KMyMoneyRegister::SelectedTransactions& transactions);
 
+  /**
+   * This signal is emitted if a specific transaction with @a transactionId in account
+   * @a accountId is selected
+   */
+  void transactionSelected(const QString accountId, const QString& transactionId);
+
   /**
     * This signal is sent out, when the user presses Ctrl+A or activates
     * the Select all transactions action.
     */
   void selectAllTransactions();
 
-  /**
-    * This signal is emitted when a new account has been selected by
-    * the GUI. If no account is selected or the selection is removed,
-    * @a account is identical to MyMoneyAccount(). This signal is used
-    * by plugins to get information about changes.
-    */
-  void accountSelected(const MyMoneyAccount& account);
-
   /**
     * This signal is emitted when a new institution has been selected by
     * the GUI. If no institution is selected or the selection is removed,
@@ -673,6 +603,8 @@ Q_SIGNALS:
   void startMatchTransaction(const MyMoneyTransaction& t);
   void cancelMatchTransaction();
 
+  void kmmFilePlugin(unsigned int);
+
 public:
 
   bool isActionToggled(const eMenu::Action _a);
@@ -688,6 +620,21 @@ private:
    */
   /// \internal d-pointer instance.
   Private* d;
+
+public Q_SLOTS:
+  bool slotFileNew();
+  void slotFileOpen();
+  bool slotFileOpenRecent(const QUrl &url);
+  bool slotFileSave();
+  bool slotFileSaveAs();
+  bool slotFileClose();
+  /**
+    * closes all open windows by calling close() on each memberList item
+    * until the list is empty, then quits the application.
+    * If queryClose() returns false because the user canceled the
+    * saveModified() dialog, the closing breaks.
+    */
+  void slotFileQuit();
 };
 
 extern KMyMoneyApp *kmymoney;
