@@ -119,7 +119,7 @@ KGuiItem KMyMoneyUtils::scheduleNewGuiItem()
 KGuiItem KMyMoneyUtils::accountsFilterGuiItem()
 {
   KGuiItem splitGuiItem(i18n("&Filter"),
-                        Icons::get(Icon::ViewFilter),
+                        Icons::get(Icon::Filter),
                         i18n("Filter out accounts"),
                         i18n("Use this to filter out accounts"));
 
@@ -165,14 +165,14 @@ bool KMyMoneyUtils::appendCorrectFileExt(QString& str, const QString& strExtToUs
   bool rc = false;
 
   if (!str.isEmpty()) {
-    //find last . delminator
+    //find last . deliminator
     int nLoc = str.lastIndexOf('.');
     if (nLoc != -1) {
       QString strExt, strTemp;
       strTemp = str.left(nLoc + 1);
       strExt = str.right(str.length() - (nLoc + 1));
       if (strExt.indexOf(strExtToUse, 0, Qt::CaseInsensitive) == -1) {
-        // if the extension given contains a period, we remove our's
+        // if the extension given contains a period, we remove ours
         if (strExtToUse.indexOf('.') != -1)
           strTemp = strTemp.left(strTemp.length() - 1);
         //append extension to make complete file name
@@ -834,3 +834,11 @@ void KMyMoneyUtils::showStatementImportResult(const QStringList& resultMessages,
                                     QStringList { i18np("No new transaction has been imported.", "No new transactions have been imported.", statementCount) },
                                 i18n("Statement import statistics"));
 }
+
+QString KMyMoneyUtils::normalizeNumericString(const qreal& val, const QLocale& loc, const char f, const int prec)
+{
+    return loc.toString(val, f, prec)
+            .remove(loc.groupSeparator())
+            .remove(QRegularExpression("0+$"))
+            .remove(QRegularExpression("\\" + loc.decimalPoint() + "$"));
+}
