@@ -1,6 +1,7 @@
 /*
  * Copyright 2010-2014  Cristian Oneț <onet.cristian@gmail.com>
  * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ * Copyright 2020       Robert Szczesiak <dev.rszczesiak@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -72,7 +73,7 @@ public:
   {
     Q_Q(AccountsModel);
     QStringList headerLabels;
-    for (const auto& column : m_columns)
+    for (const auto& column : qAsConst(m_columns))
       headerLabels.append(q->getHeaderName(column));
     q->setHorizontalHeaderLabels(headerLabels);
   }
@@ -83,14 +84,14 @@ public:
       return;
 
     auto favRow = toNode->rowCount();
-    if (auto favItem = itemFromAccountId(toNode, acc.id()))
-      favRow = favItem->row();
-
-    for (auto i = 0; i < fromNode->columnCount(); ++i) {
-      auto itemToClone = fromNode->child(row, i);
-      if (itemToClone)
-        toNode->setChild(favRow, i, itemToClone->clone());
+    if (auto favItem = itemFromAccountId(toNode, acc.id())) {
+        favRow = favItem->row();
+        toNode->removeRow(favRow);
     }
+
+    auto itemToClone = fromNode->child(row);
+    if (itemToClone)
+        toNode->insertRow(favRow, itemToClone->clone());
   }
 
   /**
@@ -360,7 +361,7 @@ public:
     MyMoneyMoney balance;
     // a closed account has a zero balance by definition
     if (!account.isClosed()) {
-      // account.balance() is not compatable with stock accounts
+      // account.balance() is not compatible with stock accounts
       if (account.isInvest())
         balance = m_file->balance(account.id());
       else
@@ -579,7 +580,7 @@ void AccountsModel::load()
     QMap<int, QVariant> itemData;
     itemData[Qt::DisplayRole] = itemData[Qt::EditRole] = itemData[(int)Role::FullName] = i18n("Favorites");
     itemData[Qt::FontRole] = font;
-    itemData[Qt::DecorationRole] = Icons::get(Icon::ViewBankAccount);
+    itemData[Qt::DecorationRole] = Icons::get(Icon::BankAccount);
     itemData[(int)Role::ID] = favoritesAccountId;
     itemData[(int)Role::DisplayOrder] = 0;
     this->setItemData(favoriteAccountsItem->index(), itemData);
@@ -646,7 +647,8 @@ void AccountsModel::load()
     }
 
     // adding accounts (specific bank/investment accounts) belonging to given accounts category
-    for (const auto& accStr : account.accountList()) {
+    const auto&  accountList = account.accountList();
+    for (const auto& accStr : accountList) {
       const auto acc = d->m_file->account(accStr);
 
       auto item = new QStandardItem(acc.name());
@@ -798,7 +800,7 @@ QString AccountsModel::getHeaderName(const Column column)
 void AccountsModel::checkNetWorth()
 {
   Q_D(AccountsModel);
-  // compute the net woth
+  // compute the net worth
   QModelIndexList assetList = match(index(0, 0),
                                     (int)Role::ID,
                                     MyMoneyFile::instance()->asset().id(),
@@ -1087,7 +1089,7 @@ public:
   void addInstitutionItem(QStandardItemModel *model, const MyMoneyInstitution &institution) {
     QFont font;
     font.setBold(true);
-    auto itInstitution = new QStandardItem(Icons::get(Icon::ViewInstitutions), institution.name());
+    auto itInstitution = new QStandardItem(Icons::get(Icon::Institution), institution.name());
     itInstitution->setFont(font);
     itInstitution->setData(QVariant::fromValue(MyMoneyMoney()), (int)Role::TotalValue);
     itInstitution->setData(institution.id(), (int)Role::ID);
@@ -1174,7 +1176,7 @@ void InstitutionsModel::slotObjectAdded(File::Object objType, const QString& id)
 
   // load the investment sub-accounts if there are any - there could be sub-accounts if this is an add operation
   // that was triggered in slotObjectModified on an already existing account which went trough a hierarchy change
-  const auto sAccounts = account.accountList();
+  const auto& sAccounts = account.accountList();
   if (!sAccounts.isEmpty()) {
     QList<MyMoneyAccount> subAccounts;
     d->m_file->accountList(subAccounts, sAccounts);
