@@ -163,6 +163,12 @@ void MyMoneySplit::setShares(const MyMoneyMoney& shares)
   d->m_shares = shares;
 }
 
+void MyMoneySplit::negateShares()
+{
+  Q_D(MyMoneySplit);
+  d->m_shares = -d->m_shares;
+}
+
 QString MyMoneySplit::value(const QString& key) const
 {
   return MyMoneyKeyValueContainer::value(key);
@@ -187,6 +193,12 @@ void MyMoneySplit::setValue(const MyMoneyMoney& value, const QString& transactio
     setShares(value);
 }
 
+void MyMoneySplit::negateValue()
+{
+    Q_D(MyMoneySplit);
+    d->m_value = -d->m_value;
+}
+
 QString MyMoneySplit::payeeId() const
 {
   Q_D(const MyMoneySplit);
