@@ -1,25 +1,22 @@
-/***************************************************************************
-                          mymoneysplit.h  -  description
-                             -------------------
-    begin                : Sun Apr 28 2002
-    copyright            : (C) 2000-2002 by Michael Edwardes
-    email                : mte@users.sourceforge.net
-                           Javier Campos Morales <javi_c@users.sourceforge.net>
-                           Felix Rodriguez <frodriguez@users.sourceforge.net>
-                           John C <thetacoturtle@users.sourceforge.net>
-                           Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           Kevin Tambascio <ktambascio@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2002-2017  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2004       Kevin Tambascio <ktambascio@users.sourceforge.net>
+ * Copyright 2005-2006  Ace Jones <acejones@users.sourceforge.net>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef MYMONEYSPLIT_H
 #define MYMONEYSPLIT_H
@@ -46,8 +43,9 @@ class QDate;
 class MyMoneyMoney;
 class MyMoneyTransaction;
 
-namespace eMyMoney { namespace Split { enum class State;
-                                       enum class InvestmentTransactionType; } }
+namespace eMyMoney { namespace Split { enum class InvestmentTransactionType; } }
+namespace eMyMoney { namespace Split { enum class State; } }
+namespace eMyMoney { namespace Split { enum class Action; } }
 
 /**
   * @author Thomas Baumgart
@@ -67,7 +65,8 @@ class KMM_MYMONEY_EXPORT MyMoneySplit : public MyMoneyObject, public MyMoneyKeyV
 public:
 
   MyMoneySplit();
-  explicit MyMoneySplit(const QDomElement& node);
+  explicit MyMoneySplit(const QString &id);
+
   MyMoneySplit(const QString& id,
                const MyMoneySplit& other);
 
@@ -86,8 +85,6 @@ public:
    */
   MyMoneySplit operator-() const;
 
-  void writeXML(QDomDocument& document, QDomElement& parent) const override;
-
   /**
     * This method checks if a reference to the given object exists. It returns,
     * a @p true if the object is referencing the one requested by the
@@ -102,6 +99,8 @@ public:
   MyMoneyMoney shares() const;
   void setShares(const MyMoneyMoney& shares);
 
+  void negateShares();
+
   /**
    * This method returns the price. If the member m_price is not zero
    * its value is returned. Otherwise, if m_shares is not zero the quotient
@@ -143,6 +142,7 @@ public:
     */
   void setValue(const MyMoneyMoney& value, const QString& transactionCurrencyId, const QString& splitCurrencyId);
 
+  void negateValue();
 
   QString accountId() const;
   void setAccountId(const QString& account);
@@ -216,22 +216,7 @@ public:
    */
   bool replaceId(const QString& newId, const QString& oldId);
 
-  static const char ActionCheck[];
-  static const char ActionDeposit[];
-  static const char ActionTransfer[];
-  static const char ActionWithdrawal[];
-  static const char ActionATM[];
-
-  static const char ActionAmortization[];
-  static const char ActionInterest[];
-
-  static const char ActionBuyShares[];  // negative amount is sellShares
-  static const char ActionDividend[];
-  static const char ActionReinvestDividend[];
-  static const char ActionYield[];
-  static const char ActionAddShares[];  // negative amount is removeShares
-  static const char ActionSplitShares[];
-  static const char ActionInterestIncome[];
+  static QString actionName(eMyMoney::Split::Action action);
 };
 
 
