@@ -1,18 +1,19 @@
-/***************************************************************************
-                          mymoneymoneytest.cpp
-                          -------------------
-    copyright            : (C) 2002 by Thomas Baumgart
-    email                : ipwizard@users.sourceforge.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2002-2011  Thomas Baumgart <tbaumgart@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "mymoneymoney-test.h"
 
@@ -37,12 +38,12 @@ void MyMoneyMoneyTest::init()
   m_2 = new MyMoneyMoney(2, 100);
   m_3 = new MyMoneyMoney(123, 1);
   m_4 = new MyMoneyMoney(1234, 1000);
-  m_5 = new MyMoneyMoney(195883, 100000);
+  m_5 = new MyMoneyMoney(static_cast<qint64>(195883), 100000);
   m_6 = new MyMoneyMoney(1.247658435, 1000000000);
 
   MyMoneyMoney::setDecimalSeparator('.');
   MyMoneyMoney::setThousandSeparator(',');
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::BeforeQuantityMoney);
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
 }
 
 void MyMoneyMoneyTest::cleanup()
@@ -74,6 +75,9 @@ void MyMoneyMoneyTest::testIntConstructor()
   QVERIFY(m_0->valueRef().get_num() == 3);
   QVERIFY(m_0->valueRef().get_den() == 25);
 
+  QVERIFY(m_5->valueRef().get_num() == 195883);
+  QVERIFY(m_5->valueRef().get_den() == 100000);
+
   MyMoneyMoney a(123, 10000);
   QVERIFY(a.valueRef().get_num() == 123);
   QVERIFY(a.valueRef().get_den() == 10000);
@@ -541,6 +545,9 @@ void MyMoneyMoneyTest::testUnaryMinus()
 
 void MyMoneyMoneyTest::testDoubleConstructor()
 {
+  QVERIFY(m_6->valueRef().get_num() == 249531687);
+  QVERIFY(m_6->valueRef().get_den() == 200000000);
+
   for (int i = -123456; i < 123456; ++i) {
     // int i = -123456;
     double d = i;
@@ -568,16 +575,9 @@ void MyMoneyMoneyTest::testToString()
   MyMoneyMoney m2(1234, 100);
   MyMoneyMoney m3;
 
-  //qDebug("Created: %s", m3.valueRef().get_str().c_str());
-
-  //QVERIFY(m1.toString() == QString("-100/100"));
-  QVERIFY(m1.toString() == QString("-1/1"));
-// qDebug("Current value: %s",qPrintable( m2.toString()) );
-  //QVERIFY(m2.toString() == QString("1234/100"));
-  QVERIFY(m2.toString() == QString("617/50"));
-  QVERIFY(m3.toString() == QString("0/1"));
-  //FIXME check the impact of the canonicalize in the whole code
-  //QVERIFY(m3.toString() == QString("0"));
+  QCOMPARE(m1.toString(), QStringLiteral("-1/1"));
+  QCOMPARE(m2.toString(), QStringLiteral("617/50"));
+  QCOMPARE(m3.toString(), QStringLiteral("0/1"));
 }
 
 void MyMoneyMoneyTest::testNegativeSignPos()
@@ -586,29 +586,55 @@ void MyMoneyMoneyTest::testNegativeSignPos()
 
   eMyMoney::Money::signPosition pos = MyMoneyMoney::negativeMonetarySignPosition();
 
+  MyMoneyMoney::setNegativeSpaceSeparatesSymbol(true);
   MyMoneyMoney::setNegativePrefixCurrencySymbol(false);
   MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::ParensAround);
-  QVERIFY(m.formatMoney("CUR", 2) == "(1,234.56) CUR");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::BeforeQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "-1,234.56 CUR");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::AfterQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "1,234.56- CUR");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::BeforeMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "1,234.56 -CUR");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::AfterMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "1,234.56 CUR-");
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(1,234.56 CUR)"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("-1,234.56 CUR"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56- CUR"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56 -CUR"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56 CUR-"));
 
   MyMoneyMoney::setNegativePrefixCurrencySymbol(true);
   MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::ParensAround);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR (1,234.56)");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::BeforeQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR -1,234.56");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::AfterQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR 1,234.56-");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::BeforeMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "-CUR 1,234.56");
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::AfterMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR- 1,234.56");
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(CUR 1,234.56)"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR -1,234.56"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR 1,234.56-"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("-CUR 1,234.56"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR- 1,234.56"));
+
+  MyMoneyMoney::setNegativeSpaceSeparatesSymbol(false);
+  MyMoneyMoney::setNegativePrefixCurrencySymbol(false);
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::ParensAround);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(1,234.56CUR)"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("-1,234.56CUR"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56-CUR"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56-CUR"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56CUR-"));
+
+  MyMoneyMoney::setNegativePrefixCurrencySymbol(true);
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::ParensAround);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(CUR1,234.56)"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR-1,234.56"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR1,234.56-"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("-CUR1,234.56"));
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR-1,234.56"));
 
   MyMoneyMoney::setNegativeMonetarySignPosition(pos);
 }
@@ -619,29 +645,56 @@ void MyMoneyMoneyTest::testPositiveSignPos()
 
   eMyMoney::Money::signPosition pos = MyMoneyMoney::positiveMonetarySignPosition();
 
+  MyMoneyMoney::setPositiveSpaceSeparatesSymbol(true);
   MyMoneyMoney::setPositivePrefixCurrencySymbol(false);
   MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::ParensAround);
-  QVERIFY(m.formatMoney("CUR", 2) == "(1,234.56) CUR");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::BeforeQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "1,234.56 CUR");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::AfterQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "1,234.56 CUR");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::BeforeMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "1,234.56 CUR");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::AfterMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "1,234.56 CUR");
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(1,234.56 CUR)"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56 CUR"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56 CUR"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56 CUR"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56 CUR"));
 
   MyMoneyMoney::setPositivePrefixCurrencySymbol(true);
   MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::ParensAround);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR (1,234.56)");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::BeforeQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR 1,234.56");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::AfterQuantityMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR 1,234.56");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::BeforeMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR 1,234.56");
-  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::AfterMoney);
-  QVERIFY(m.formatMoney("CUR", 2) == "CUR 1,234.56");
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(CUR 1,234.56)"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR 1,234.56"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR 1,234.56"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR 1,234.56"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR 1,234.56"));
+
+  MyMoneyMoney::setPositiveSpaceSeparatesSymbol(false);
+  MyMoneyMoney::setPositivePrefixCurrencySymbol(false);
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::ParensAround);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(1,234.56CUR)"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56CUR"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56CUR"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56CUR"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("1,234.56CUR"));
+
+  MyMoneyMoney::setPositivePrefixCurrencySymbol(true);
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::ParensAround);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("(CUR1,234.56)"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR1,234.56"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedQuantityAndSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR1,234.56"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::PreceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR1,234.56"));
+  MyMoneyMoney::setPositiveMonetarySignPosition(eMyMoney::Money::SucceedSymbol);
+  QCOMPARE(m.formatMoney("CUR", 2), QStringLiteral("CUR1,234.56"));
+
 
   MyMoneyMoney::setPositiveMonetarySignPosition(pos);
 }
@@ -658,7 +711,7 @@ void MyMoneyMoneyTest::testNegativeStringConstructor()
   QVERIFY(m1->valueRef().get_den() == 1000);
   delete m1;
 
-  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::BeforeQuantityMoney);
+  MyMoneyMoney::setNegativeMonetarySignPosition(eMyMoney::Money::PreceedQuantityAndSymbol);
   m1 = new MyMoneyMoney("x1.234,567- EUR");
   //qDebug("Created: %s", m1->valueRef().get_str().c_str());
 
@@ -693,15 +746,6 @@ void MyMoneyMoneyTest::testReduce()
 
 void MyMoneyMoneyTest::testZeroDenominator()
 {
-  try {
-    MyMoneyMoney m((int)1, 0);
-    QFAIL("Missing expected exception");
-  } catch (const MyMoneyException &) {
-  }
-
-  try {
-    MyMoneyMoney m((signed64)1, 0);
-    QFAIL("Missing expected exception");
-  } catch (const MyMoneyException &) {
-  }
+  QVERIFY_EXCEPTION_THROWN(MyMoneyMoney m((int)1, 0), MyMoneyException);
+  QVERIFY_EXCEPTION_THROWN(MyMoneyMoney m((signed64)1, 0), MyMoneyException);
 }
