@@ -44,7 +44,7 @@ void MyMoneyScheduleTest::testEmptyConstructor()
   MyMoneySchedule s;
 
   QCOMPARE(s.id().isEmpty(), true);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::Any);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Any);
   QCOMPARE(s.type(), Schedule::Type::Any);
   QCOMPARE(s.paymentType(), Schedule::PaymentType::Any);
   QCOMPARE(s.isFinished(), false);
@@ -69,7 +69,7 @@ void MyMoneyScheduleTest::testConstructor()
                     true);
 
   QCOMPARE(s.type(), Schedule::Type::Bill);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrenceMultiplier(), 1);
   QCOMPARE(s.paymentType(), Schedule::PaymentType::DirectDebit);
   QCOMPARE(s.startDate(), QDate());
@@ -540,190 +540,190 @@ void MyMoneyScheduleTest::testOccurrencePeriod()
   s.setLastPayment(s.startDate());
   // Set all base occurrences
   s.setOccurrencePeriod(Schedule::Occurrence::Once);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Once);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Once);
   s.setOccurrenceMultiplier(1);
   QCOMPARE(s.occurrenceMultiplier(), 1);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Once);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Once);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Once);
   s.setOccurrenceMultiplier(2);
   QCOMPARE(s.occurrenceMultiplier(), 2);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Once);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Once);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Once);
 
   s.setOccurrencePeriod(Schedule::Occurrence::Daily);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Daily);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Daily);
   s.setOccurrenceMultiplier(1);
   QCOMPARE(s.occurrenceMultiplier(), 1);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Daily);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Daily);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Daily);
   s.setOccurrenceMultiplier(30);
   QCOMPARE(s.occurrenceMultiplier(), 30);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Daily);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryThirtyDays);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Daily);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryThirtyDays);
   s.setOccurrenceMultiplier(2);
   QCOMPARE(s.occurrenceMultiplier(), 2);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Daily);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Daily);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Daily);
 
   s.setOccurrencePeriod(Schedule::Occurrence::Weekly);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
   s.setOccurrenceMultiplier(1);
   QCOMPARE(s.occurrenceMultiplier(), 1);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Weekly);
   s.setOccurrenceMultiplier(2);
   QCOMPARE(s.occurrenceMultiplier(), 2);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryOtherWeek);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryOtherWeek);
   s.setOccurrenceMultiplier(3);
   QCOMPARE(s.occurrenceMultiplier(), 3);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryThreeWeeks);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryThreeWeeks);
   s.setOccurrenceMultiplier(4);
   QCOMPARE(s.occurrenceMultiplier(), 4);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryFourWeeks);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryFourWeeks);
   s.setOccurrenceMultiplier(5);
   QCOMPARE(s.occurrenceMultiplier(), 5);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Weekly);
   s.setOccurrenceMultiplier(8);
   QCOMPARE(s.occurrenceMultiplier(), 8);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryEightWeeks);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryEightWeeks);
 
   s.setOccurrencePeriod(Schedule::Occurrence::EveryHalfMonth);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::EveryHalfMonth);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryHalfMonth);
   s.setOccurrenceMultiplier(1);
   QCOMPARE(s.occurrenceMultiplier(), 1);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::EveryHalfMonth);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryHalfMonth);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryHalfMonth);
   s.setOccurrenceMultiplier(2);
   QCOMPARE(s.occurrenceMultiplier(), 2);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::EveryHalfMonth);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryHalfMonth);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryHalfMonth);
 
   s.setOccurrencePeriod(Schedule::Occurrence::Monthly);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
   s.setOccurrenceMultiplier(1);
   QCOMPARE(s.occurrenceMultiplier(), 1);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Monthly);
   s.setOccurrenceMultiplier(2);
   QCOMPARE(s.occurrenceMultiplier(), 2);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryOtherMonth);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryOtherMonth);
   s.setOccurrenceMultiplier(3);
   QCOMPARE(s.occurrenceMultiplier(), 3);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryThreeMonths);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryThreeMonths);
   s.setOccurrenceMultiplier(4);
   QCOMPARE(s.occurrenceMultiplier(), 4);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryFourMonths);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryFourMonths);
   s.setOccurrenceMultiplier(5);
   QCOMPARE(s.occurrenceMultiplier(), 5);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Monthly);
   s.setOccurrenceMultiplier(6);
   QCOMPARE(s.occurrenceMultiplier(), 6);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::TwiceYearly);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::TwiceYearly);
 
   s.setOccurrencePeriod(Schedule::Occurrence::Yearly);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Yearly);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Yearly);
   s.setOccurrenceMultiplier(1);
   QCOMPARE(s.occurrenceMultiplier(), 1);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Yearly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Yearly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Yearly);
   s.setOccurrenceMultiplier(2);
   QCOMPARE(s.occurrenceMultiplier(), 2);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Yearly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryOtherYear);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Yearly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryOtherYear);
   s.setOccurrenceMultiplier(3);
   QCOMPARE(s.occurrenceMultiplier(), 3);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Yearly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Yearly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Yearly);
 
   // Set occurrence: check occurrence, Period and Multiplier
   s.setOccurrence(Schedule::Occurrence::Once);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Once);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Once);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Once);
   QCOMPARE(s.occurrenceMultiplier(), 1);
 
   s.setOccurrence(Schedule::Occurrence::Daily);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Daily);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Daily);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Daily);
   QCOMPARE(s.occurrenceMultiplier(), 1);
   s.setOccurrence(Schedule::Occurrence::EveryThirtyDays);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryThirtyDays);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Daily);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryThirtyDays);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Daily);
   QCOMPARE(s.occurrenceMultiplier(), 30);
 
   s.setOccurrence(Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrenceMultiplier(), 1);
   s.setOccurrence(Schedule::Occurrence::EveryOtherWeek);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryOtherWeek);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryOtherWeek);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrenceMultiplier(), 2);
   // Fortnightly no longer used: Every other week used instead
   s.setOccurrence(Schedule::Occurrence::Fortnightly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryOtherWeek);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryOtherWeek);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrenceMultiplier(), 2);
   s.setOccurrence(Schedule::Occurrence::EveryThreeWeeks);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryThreeWeeks);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryThreeWeeks);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrenceMultiplier(), 3);
   s.setOccurrence(Schedule::Occurrence::EveryFourWeeks);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryFourWeeks);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryFourWeeks);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrenceMultiplier(), 4);
   s.setOccurrence(Schedule::Occurrence::EveryEightWeeks);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryEightWeeks);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Weekly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryEightWeeks);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Weekly);
   QCOMPARE(s.occurrenceMultiplier(), 8);
 
   s.setOccurrence(Schedule::Occurrence::EveryHalfMonth);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryHalfMonth);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryHalfMonth);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::EveryHalfMonth);
   QCOMPARE(s.occurrenceMultiplier(), 1);
 
   s.setOccurrence(Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrenceMultiplier(), 1);
   s.setOccurrence(Schedule::Occurrence::EveryOtherMonth);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryOtherMonth);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryOtherMonth);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrenceMultiplier(), 2);
   s.setOccurrence(Schedule::Occurrence::EveryThreeMonths);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryThreeMonths);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryThreeMonths);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrenceMultiplier(), 3);
   // Quarterly no longer used.  Every three months used instead
   s.setOccurrence(Schedule::Occurrence::Quarterly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryThreeMonths);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryThreeMonths);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrenceMultiplier(), 3);
   s.setOccurrence(Schedule::Occurrence::EveryFourMonths);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryFourMonths);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryFourMonths);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrenceMultiplier(), 4);
   s.setOccurrence(Schedule::Occurrence::TwiceYearly);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::TwiceYearly);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Monthly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::TwiceYearly);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Monthly);
   QCOMPARE(s.occurrenceMultiplier(), 6);
 
   s.setOccurrence(Schedule::Occurrence::Yearly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::Yearly);
   QCOMPARE(s.occurrence(), Schedule::Occurrence::Yearly);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Yearly);
   QCOMPARE(s.occurrenceMultiplier(), 1);
   s.setOccurrence(Schedule::Occurrence::EveryOtherYear);
-  QCOMPARE(s.occurrence(), Schedule::Occurrence::EveryOtherYear);
-  QCOMPARE(s.occurrencePeriod(), Schedule::Occurrence::Yearly);
+  QCOMPARE(s.baseOccurrence(), Schedule::Occurrence::EveryOtherYear);
+  QCOMPARE(s.occurrence(), Schedule::Occurrence::Yearly);
   QCOMPARE(s.occurrenceMultiplier(), 2);
 }
 
@@ -848,7 +848,7 @@ void MyMoneyScheduleTest::testProcessingDates()
   // make sure fall back works
 
   MyMoneySchedule s;
-  // Check there is no processing caledar defined.
+  // Check there is no processing calendar defined.
   QVERIFY(s.processingCalendar() == nullptr);
   // This should be a processing day.
   QCOMPARE(s.isProcessingDate(QDate(2009, 12, 31)), true);
