@@ -495,7 +495,7 @@ eMyMoney::Transaction::Action CSVImporterCore::processActionTypeField(const Inve
   QString type = m_file->m_model->item(row, col)->text();
   QList<eMyMoney::Transaction::Action> actions;
   actions << eMyMoney::Transaction::Action::Buy << eMyMoney::Transaction::Action::Sell <<                       // first and second most frequent action
-             eMyMoney::Transaction::Action::ReinvestDividend << eMyMoney::Transaction::Action::CashDividend <<  // we don't want "reinv-dividend" to be accidentaly caught by "dividend"
+             eMyMoney::Transaction::Action::ReinvestDividend << eMyMoney::Transaction::Action::CashDividend <<  // we don't want "reinv-dividend" to be accidentally caught by "dividend"
              eMyMoney::Transaction::Action::Interest <<
              eMyMoney::Transaction::Action::Shrsin << eMyMoney::Transaction::Action::Shrsout;
 
@@ -612,7 +612,7 @@ DecimalSymbol CSVImporterCore::detectDecimalSymbol(const int col, const QString
         dotIsDecimalSeparator = true;
       else if (dotPos < commaPos && dotIsDecimalSeparator == false) // following case 1.234,56
         commaIsDecimalSeparator = true;
-      else                                                          // following case 1.234,56 and somwhere earlier there was 1,234.56 so unresolvable conflict
+      else                                                          // following case 1.234,56 and somewhere earlier there was 1,234.56 so unresolvable conflict
         return detectedSymbol;
     } else if (dotPos != -1) {                 // following case 1.23
       if (dotIsDecimalSeparator)               // it's already know that dotIsDecimalSeparator
@@ -622,9 +622,9 @@ DecimalSymbol CSVImporterCore::detectDecimalSymbol(const int col, const QString
       else {
         if (txt.count(QLatin1Char('.')) > 1)                // following case 1.234.567 so OK
           continue;
-        else if (txt.length() - 4 == dotPos)   // following case 1.234 and somwhere earlier there was 1.234,56 so OK
+        else if (txt.length() - 4 == dotPos)   // following case 1.234 and somewhere earlier there was 1.234,56 so OK
           continue;
-        else                                   // following case 1.23 and somwhere earlier there was 1,23 so unresolvable conflict
+        else                                   // following case 1.23 and somewhere earlier there was 1,23 so unresolvable conflict
           return detectedSymbol;
       }
     } else if (commaPos != -1) {               // following case 1,23
@@ -635,9 +635,9 @@ DecimalSymbol CSVImporterCore::detectDecimalSymbol(const int col, const QString
       else {
         if (txt.count(QLatin1Char(',')) > 1)                // following case 1,234,567 so OK
           continue;
-        else if (txt.length() - 4 == commaPos) // following case 1,234 and somwhere earlier there was 1,234.56 so OK
+        else if (txt.length() - 4 == commaPos) // following case 1,234 and somewhere earlier there was 1,234.56 so OK
           continue;
-        else                                   // following case 1,23 and somwhere earlier there was 1.23 so unresolvable conflict
+        else                                   // following case 1,23 and somewhere earlier there was 1.23 so unresolvable conflict
           return detectedSymbol;
       }
 
@@ -861,6 +861,9 @@ bool CSVImporterCore::processBankRow(MyMoneyStatement &st, const BankingProfile
   QString memo;
   QString txt;
 
+  if (!profile)
+    return false;
+
   // process date field
   int col = profile->m_colTypeNum.value(Column::Date, -1);
   tr.m_datePosted = processDateField(row, col);
@@ -890,6 +893,10 @@ bool CSVImporterCore::processBankRow(MyMoneyStatement &st, const BankingProfile
         memo.append(m_file->m_model->item(row, profile->m_memoColList.at(i))->text());
     }
   }
+  // remove unnecessary line endings
+  while (memo.endsWith(QLatin1Char('\n'))) {
+    memo.resize(memo.length()-1);
+  }
   tr.m_strMemo = memo;
 
   // process amount field
@@ -953,6 +960,9 @@ bool CSVImporterCore::processInvestRow(MyMoneyStatement &st, const InvestmentPro
 {
   MyMoneyStatement::Transaction tr;
 
+  if (!profile)
+    return false;
+
   QString memo;
   QString txt;
   // process date field
@@ -1031,6 +1041,10 @@ bool CSVImporterCore::processInvestRow(MyMoneyStatement &st, const InvestmentPro
         memo.append(m_file->m_model->item(row, profile->m_memoColList.at(i))->text());
     }
   }
+  // remove unnecessary line endings
+  while (memo.endsWith(QLatin1Char('\n'))) {
+    memo.resize(memo.length()-1);
+  }
   tr.m_strMemo = memo;
 
   tr.m_strInterestCategory.clear(); // no special category
@@ -1064,6 +1078,9 @@ bool CSVImporterCore::processPriceRow(MyMoneyStatement &st, const PricesProfile
 {
   MyMoneyStatement::Price pr;
 
+  if (!profile)
+    return false;
+
   // process date field
   int col = profile->m_colTypeNum.value(Column::Date, -1);
   pr.m_date = processDateField(row, col);
@@ -1640,7 +1657,9 @@ CSVFile::~CSVFile()
 void CSVFile::getStartEndRow(CSVProfile *profile)
 {
   profile->m_endLine = m_rowCount - 1;
-  if (profile->m_endLine > profile->m_trailerLines)
+
+  // if trailer lines are specified then remove them here
+  if (profile->m_trailerLines)
     profile->m_endLine -= profile->m_trailerLines;
 
   if (profile->m_startLine > profile->m_endLine)   // Don't allow m_startLine > m_endLine
