@@ -1,21 +1,21 @@
-/***************************************************************************
-                        csvdatetest.cpp
-                      -------------------
-begin                : Sat Jan 01 2010
-copyright            : (C) 2010 by Allan Anderson
-email                : agander93@gmail.com
-copyright            : (C) 2017 by Łukasz Wojniłowicz
-email                : lukasz.wojnilowicz@gmail.com
-***************************************************************************/
+/*
+ * Copyright 2010-2012  Allan Anderson <agander93@gmail.com>
+ * Copyright 2017  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
-/***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
 #include "csvdate-test.h"
 
 #include <QtTest>
