@@ -1,25 +1,27 @@
-/***************************************************************************
-                        csvimportercore.cpp
-                      -------------------
-copyright            : (C) 2017 by Łukasz Wojniłowicz
-email                : lukasz.wojnilowicz@gmail.com
-***************************************************************************/
+/*
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
-/***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
 #include "csvimportercore-test.h"
 
 #include <QtTest>
 
 #include "mymoneyfile.h"
 #include "mymoneyaccount.h"
-#include <mymoneyseqaccessmgr.h>
+#include <mymoneystoragemgr.h>
 
 #include "csvimportercore.h"
 #include "csvimporttestcommon.h"
@@ -35,7 +37,7 @@ void CSVImporterCoreTest::initTestCase()
 
 void CSVImporterCoreTest::init()
 {
-  storage = new MyMoneySeqAccessMgr;
+  storage = new MyMoneyStorageMgr;
   file = MyMoneyFile::instance();
   file->attachStorage(storage);
 
