@@ -113,7 +113,7 @@ struct icalrecurrencetype scheduleToRecurenceRule(const MyMoneySchedule& schedul
   recurrence.week_start = icalrecurrencetype_day_day_of_week(QLocale().firstDayOfWeek());
   int frequencyFactor = 1; // used to translate kmymoney frequency to icalendar frequency
 
-  switch (schedule.occurrence()) {
+  switch (schedule.baseOccurrence()) {
     case Schedule::Occurrence::Daily:
       recurrence.freq = ICAL_DAILY_RECURRENCE;
       break;
@@ -342,7 +342,7 @@ void KMMSchedulesToiCalendar::exportToFile(const QString& filePath, bool setting
     if (pRRule != 0) {
       icalcomponent_remove_property(schedule, pRRule);
     }
-    if (myMoneySchedule.occurrence() != Schedule::Occurrence::Once && myMoneySchedule.occurrence() != Schedule::Occurrence::Any)
+    if (myMoneySchedule.occurrence() != Schedule::Occurrence::Once && myMoneySchedule.baseOccurrence() != Schedule::Occurrence::Any)
       icalcomponent_add_property(schedule, icalproperty_new_rrule(scheduleToRecurenceRule(myMoneySchedule)));
 
     icalcomponent* oldAlarm = icalcomponent_get_first_component(schedule, ICAL_VALARM_COMPONENT);
@@ -350,7 +350,7 @@ void KMMSchedulesToiCalendar::exportToFile(const QString& filePath, bool setting
       icalcomponent_remove_component(schedule, oldAlarm);
 
     if (PluginSettings::createAlarm() && (!oldAlarm || settingsChaged)) {
-      // alarm: beginning wiht one day before the todo is due every one hour
+      // alarm: beginning with one day before the todo is due every one hour
       icalcomponent* alarm = icalcomponent_new_valarm();
       // alarm: action
       icalcomponent_add_property(alarm, icalproperty_new_action(ICAL_ACTION_DISPLAY));
@@ -370,7 +370,7 @@ void KMMSchedulesToiCalendar::exportToFile(const QString& filePath, bool setting
       icalcomponent_add_component(schedule, alarm);
     }
 
-    // add the schedule to the caledar
+    // add the schedule to the calendar
     if (newTodo)
       icalcomponent_add_component(vCalendar, schedule);
   }
