@@ -280,8 +280,14 @@ void QueryTable::constructTotalRows()
   for (int i = 0; i < rows-1; ++i) {
     // it should be unlikely that total row is at the top of rows, so...
     if ((m_rows.at(i)[ctRank] == QLatin1String("5")) || (m_rows.at(i)[ctTopAccount].isEmpty())) {
-      m_rows.move(i, rows - 1);                       // ...move it at the end
-      --i; // check the same slot again
+      // check if there are other entries than totals so moving makes sense
+      for (int j = i+1; j <= rows-1; ++j) {
+        if ((m_rows.at(j)[ctRank] != QLatin1String("5")) && (!m_rows.at(j)[ctTopAccount].isEmpty())) {
+          m_rows.move(i, rows - 1);                   // ...move it at the end
+          --i;                                        // check the same slot again
+          break;
+        }
+      }
     } else if (m_rows.at(i)[ctRank] == QLatin1String("4")) {
       // search last entry of same topAccount
       auto last = i+1;
@@ -471,6 +477,9 @@ void QueryTable::constructTotalRows()
         totalsRow[ctDepth] = QString();
 
         m_rows.append(totalsRow);
+        if (!m_containsNonBaseCurrency && totalsRow[ctCurrency] != file->baseCurrency().id()) {
+          m_containsNonBaseCurrency = true;
+        }
         ++currencyGrp;
       }
       break;                                      // no use to loop further
@@ -531,6 +540,8 @@ void QueryTable::constructTransactionTable()
   for (QList<MyMoneyTransaction>::const_iterator it_transaction = transactions.constBegin(); it_transaction != transactions.constEnd(); ++it_transaction) {
 
     TableRow qA, qS;
+    QList<TableRow> qStack;
+
     QDate pd;
     QList<QString> tagIdListCache;
 
@@ -543,8 +554,6 @@ void QueryTable::constructTransactionTable()
     qA[ctMonth] = qS[ctMonth] = i18n("Month of %1", QDate(pd.year(), pd.month(), 1).toString(Qt::ISODate));
     qA[ctWeek] = qS[ctWeek] = i18n("Week of %1", pd.addDays(1 - pd.dayOfWeek()).toString(Qt::ISODate));
 
-    if (!m_containsNonBaseCurrency && (*it_transaction).commodity() != file->baseCurrency().id())
-      m_containsNonBaseCurrency = true;
     if (report.isConvertCurrency())
       qA[ctCurrency] = qS[ctCurrency] = file->baseCurrency().id();
     else
@@ -620,6 +629,7 @@ void QueryTable::constructTransactionTable()
     QString baseCurrency = file->baseCurrency().id();
 
     QMap<QString, MyMoneyMoney> xrMap; // container for conversion rates from given currency to myBeginCurrency
+
     do {
       MyMoneyMoney xr;
       ReportAccount splitAcc((* it_split).accountId());
@@ -651,8 +661,6 @@ void QueryTable::constructTransactionTable()
         else if (splitAcc.isInvest())         // if it's stock split...
           xr *= (*it_split).price();          // ...multiply it by stock price stored in split
 
-        if (!m_containsNonBaseCurrency && myBeginCurrency != baseCurrency)
-          m_containsNonBaseCurrency = true;
         if (myBeginCurrency != baseCurrency) {                             // myBeginCurrency can differ from baseCurrency...
           MyMoneyPrice price = file->price(myBeginCurrency, baseCurrency,
                                            (*it_transaction).postDate());  // ...so check conversion rate...
@@ -710,8 +718,6 @@ void QueryTable::constructTransactionTable()
                 splitAcc = ReportAccount(assetAccountSplit.accountId()); // switch over from stock split to asset split because amount in stock split doesn't take fees/interests into account
                 myBegin = it_split;                       // set myBegin to asset split, so stock split can be listed in details under splits
                 myBeginCurrency = (file->account((*myBegin).accountId())).currencyId();
-                if (!m_containsNonBaseCurrency && myBeginCurrency != baseCurrency)
-                  m_containsNonBaseCurrency = true;
                 if (m_config.isConvertCurrency()) {
                   if (myBeginCurrency != baseCurrency) {
                     MyMoneyPrice price = file->price(myBeginCurrency, baseCurrency, (*it_transaction).postDate());
@@ -786,7 +792,6 @@ void QueryTable::constructTransactionTable()
 
           } else {
             if ((splits.count() > 2) && use_summary) {
-
               // add the "summarized" split transaction
               // this is the sub-total of the split detail
               // convert to lowest fraction
@@ -795,6 +800,32 @@ void QueryTable::constructTransactionTable()
               qA[ctTopCategory] = i18nc("Split transaction", "Split");
               qA[ctCategoryType] = i18nc("Split transaction", "Split");
               m_rows += qA;
+              if (!m_containsNonBaseCurrency && qA[ctCurrency] != file->baseCurrency().id()) {
+                m_containsNonBaseCurrency = true;
+              }
+            } else if (splits.count() > 2) {
+              // this applies when the transaction has more than 2 splits
+              // and each is shown seperately
+              switch (m_config.rowType()) {
+                case eMyMoney::Report::RowType::Category:
+                case eMyMoney::Report::RowType::TopCategory:
+                case eMyMoney::Report::RowType::Tag:
+                case eMyMoney::Report::RowType::Payee:
+                  if (splitAcc.isAssetLiability()) {
+                    qA[ctValue] = ((*it_split).shares() * xr).convert(fraction).toString(); // needed for category reports, in case of multicurrency transaction it breaks it
+                    // make sure we use the right currency of the category
+                    // (will be ignored when converting to base currency)
+                    qA[ctCurrency] = splitAcc.currencyId();
+                  }
+                  break;
+                default:
+                  break;
+              }
+              qA[ctSplit].clear();
+              qA[ctRank] = QLatin1Char('1');
+              // keep it for now and don't add the data immediately
+              // as we may find a better match in one of the other splits
+              qStack += qA;
             }
           }
         }
@@ -858,8 +889,12 @@ void QueryTable::constructTransactionTable()
                 case eMyMoney::Report::RowType::TopCategory:
                 case eMyMoney::Report::RowType::Tag:
                 case eMyMoney::Report::RowType::Payee:
-                  if (splitAcc.isIncomeExpense())
+                  if (splitAcc.isIncomeExpense()) {
                     qA[ctValue] = (-(*it_split).shares() * xr).convert(fraction).toString(); // needed for category reports, in case of multicurrency transaction it breaks it
+                    // make sure we use the right currency of the category
+                    // (will be ignored when converting to base currency)
+                    qA[ctCurrency] = splitAcc.currencyId();
+                  }
                   break;
                 default:
                   break;
@@ -870,8 +905,6 @@ void QueryTable::constructTransactionTable()
 
             qA [ctMemo] = (*it_split).memo();
 
-            if (!m_containsNonBaseCurrency && splitAcc.currencyId() != file->baseCurrency().id())
-              m_containsNonBaseCurrency = true;
             if (report.isConvertCurrency())
               qS[ctCurrency] = file->baseCurrency().id();
             else
@@ -913,6 +946,12 @@ void QueryTable::constructTransactionTable()
                     }
                   }
                   m_rows += qA;
+                  if (!m_containsNonBaseCurrency && qA[ctCurrency] != file->baseCurrency().id()) {
+                    m_containsNonBaseCurrency = true;
+                  }
+
+                  // we don't need the stacked data
+                  qStack.clear();
                 }
               }
             }
@@ -971,6 +1010,10 @@ void QueryTable::constructTransactionTable()
                     && (transaction_text
                         || m_config.match((*it_split))))) {
               m_rows += qS;
+              qStack.clear();
+              if (!m_containsNonBaseCurrency && qS[ctCurrency] != file->baseCurrency().id()) {
+                m_containsNonBaseCurrency = true;
+              }
 
               // track accts that will need opening and closing balances
               accts.insert(splitAcc.id(), splitAcc);
@@ -996,9 +1039,22 @@ void QueryTable::constructTransactionTable()
         break;
 
     } while (it_split != myBegin);
+
     if (loan_special_case) {
       m_rows += qA;
+      if (!m_containsNonBaseCurrency && qA[ctCurrency] != file->baseCurrency().id()) {
+        m_containsNonBaseCurrency = true;
+      }
+      qStack.clear();
     }
+    // check if the stack contains a foreign currency
+    for (const auto& row : qAsConst(qStack)) {
+      if (!m_containsNonBaseCurrency && row[ctCurrency] != file->baseCurrency().id()) {
+        m_containsNonBaseCurrency = true;
+        break;
+      }
+    }
+    m_rows += qStack;
   }
 
   // now run through our accts list and add opening and closing balances
@@ -1062,8 +1118,6 @@ void QueryTable::constructTransactionTable()
 
     //starting balance
     // don't show currency if we're converting or if it's not foreign
-    if (!m_containsNonBaseCurrency && account.currency().id() != file->baseCurrency().id())
-      m_containsNonBaseCurrency = true;
     if (m_config.isConvertCurrency())
       qA[ctCurrency] = file->baseCurrency().id();
     else
@@ -1098,6 +1152,9 @@ void QueryTable::constructTransactionTable()
     qA[ctRank] = QLatin1Char('3');
     qA[ctID] = QLatin1Char('Z');
     m_rows += qA;
+    if (!m_containsNonBaseCurrency && qA[ctCurrency] != file->baseCurrency().id()) {
+      m_containsNonBaseCurrency = true;
+    }
   }
 }
 
@@ -1567,8 +1624,6 @@ void QueryTable::constructAccountTable()
           if (!qaccountrow.isEmpty()) {
             // assuming that that report is grouped by topaccount
             qaccountrow[ctTopAccount] = account.topParentName();
-            if (!m_containsNonBaseCurrency && account.currency().id() != file->baseCurrency().id())
-              m_containsNonBaseCurrency = true;
             if (m_config.isConvertCurrency())
               qaccountrow[ctCurrency] = file->baseCurrency().id();
             else
@@ -1618,13 +1673,14 @@ void QueryTable::constructAccountTable()
       qaccountrow[ctAccount] = account.name();
       qaccountrow[ctAccountID] = account.id();
       qaccountrow[ctTopAccount] = account.topParentName();
-      if (!m_containsNonBaseCurrency && account.currency().id() != file->baseCurrency().id())
-        m_containsNonBaseCurrency = true;
       if (m_config.isConvertCurrency())
         qaccountrow[ctCurrency] = file->baseCurrency().id();
       else
         qaccountrow[ctCurrency] = account.currency().id();
       m_rows.append(qaccountrow);
+      if (!m_containsNonBaseCurrency && qaccountrow[ctCurrency] != file->baseCurrency().id()) {
+        m_containsNonBaseCurrency = true;
+      }
     }
   }
 
@@ -1642,6 +1698,9 @@ void QueryTable::constructAccountTable()
         qtotalsrow[ctCurrency] = currencyAccGrp.key();
         currencyGrandCashFlow[currencyAccGrp.key()] += topAccount.value();  // cumulative sum of cashflows of each topaccount
         m_rows.append(qtotalsrow);            // rows aren't sorted yet, so no problem with adding them randomly at the end
+        if (!m_containsNonBaseCurrency && qtotalsrow[ctCurrency] != file->baseCurrency().id()) {
+          m_containsNonBaseCurrency = true;
+        }
       }
       ++currencyAccGrp;
     }
@@ -1651,6 +1710,9 @@ void QueryTable::constructAccountTable()
       qtotalsrow[ctReturn] = helperIRR(currencyGrp.value());
       qtotalsrow[ctCurrency] = currencyGrp.key();
       m_rows.append(qtotalsrow);
+      if (!m_containsNonBaseCurrency && qtotalsrow[ctCurrency] != file->baseCurrency().id()) {
+        m_containsNonBaseCurrency = true;
+      }
       ++currencyGrp;
     }
   }
@@ -1686,8 +1748,6 @@ void QueryTable::constructSplitsTable()
     qA[ctMonth] = qS[ctMonth] = i18n("Month of %1", QDate(pd.year(), pd.month(), 1).toString(Qt::ISODate));
     qA[ctWeek] = qS[ctWeek] = i18n("Week of %1", pd.addDays(1 - pd.dayOfWeek()).toString(Qt::ISODate));
 
-    if (!m_containsNonBaseCurrency && (*it_transaction).commodity() != file->baseCurrency().id())
-      m_containsNonBaseCurrency = true;
     if (report.isConvertCurrency())
       qA[ctCurrency] = qS[ctCurrency] = file->baseCurrency().id();
     else
@@ -1886,6 +1946,9 @@ void QueryTable::constructSplitsTable()
         qA [ctCategoryType] = MyMoneyAccount::accountTypeToString(splitAcc.accountGroup());
 
         m_rows += qA;
+        if (!m_containsNonBaseCurrency && qA[ctCurrency] != file->baseCurrency().id()) {
+          m_containsNonBaseCurrency = true;
+        }
 
         // track accts that will need opening and closing balances
         accts.insert(splitAcc.id(), splitAcc);
@@ -1906,6 +1969,9 @@ void QueryTable::constructSplitsTable()
 
     if (loan_special_case) {
       m_rows += qA;
+      if (!m_containsNonBaseCurrency && qA[ctCurrency] != file->baseCurrency().id()) {
+        m_containsNonBaseCurrency = true;
+      }
     }
   }
 
@@ -1970,8 +2036,6 @@ void QueryTable::constructSplitsTable()
 
     //starting balance
     // don't show currency if we're converting or if it's not foreign
-    if (!m_containsNonBaseCurrency && account.currency().id() != file->baseCurrency().id())
-      m_containsNonBaseCurrency = true;
     if (m_config.isConvertCurrency())
       qA[ctCurrency] = file->baseCurrency().id();
     else
@@ -2007,6 +2071,9 @@ void QueryTable::constructSplitsTable()
     qA[ctBalance] = endBalance.toString();
     qA[ctID] = QLatin1Char('Z');
     m_rows += qA;
+    if (!m_containsNonBaseCurrency && qA[ctCurrency] != file->baseCurrency().id()) {
+      m_containsNonBaseCurrency = true;
+    }
   }
 }
 
