@@ -11,6 +11,7 @@
                            Kevin Tambascio <ktambascio@users.sourceforge.net>
                            Ace Jones <ace.j@hotpop.com>
                            (C) 2017, 2018 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+                           2018 by Michael Kiefer <Michael-Kiefer@web.de>
  ***************************************************************************/
 
 /***************************************************************************
@@ -130,9 +131,9 @@ KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(MyMoneyReport repor
   //
   if (d->m_initialState.reportType() == eMyMoney::Report::ReportType::PivotTable) {
     // we will use date range together with data range
-    d->m_tabFilters = new KTransactionFilter(this, (report.rowType() == eMyMoney::Report::RowType::Account), false);
+    d->m_tabFilters = new KTransactionFilter(this, (report.rowType() == eMyMoney::Report::RowType::Account), false, false);
   } else {
-    d->m_tabFilters = new KTransactionFilter(this, (report.rowType() == eMyMoney::Report::RowType::Account));
+    d->m_tabFilters = new KTransactionFilter(this, (report.rowType() == eMyMoney::Report::RowType::Account), report.isInvestmentsOnly());
     d->m_dateRange = d->m_tabFilters->dateRange();
   }
 
@@ -165,6 +166,7 @@ KReportConfigurationFilterDlg::KReportConfigurationFilterDlg(MyMoneyReport repor
       connect(d->m_tabRange->ui->m_comboColumns, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, static_cast<void (KReportConfigurationFilterDlg::*)(int)>(&KReportConfigurationFilterDlg::slotUpdateColumnsCombo));
     }
     connect(d->m_tabChart->ui->m_logYaxis, &QCheckBox::stateChanged, this, &KReportConfigurationFilterDlg::slotLogAxisChanged);
+    connect(d->m_tabChart->ui->m_negExpenses, &QCheckBox::stateChanged, this, &KReportConfigurationFilterDlg::slotNegExpensesChanged);
   } else if (d->m_initialState.reportType() == eMyMoney::Report::ReportType::QueryTable) {
     // eInvestmentHoldings is a special-case report, and you cannot configure the
     // rows & columns of that report.
@@ -298,18 +300,22 @@ void KReportConfigurationFilterDlg::slotSearch()
                                   eMyMoney::Report::DetailLevel::None : eMyMoney::Report::DetailLevel::All);
     d->m_currentState.setHideTransactions(d->m_tabRowColQuery->ui->m_checkHideTransactions->isChecked());
     d->m_currentState.setShowingColumnTotals(!d->m_tabRowColQuery->ui->m_checkHideTotals->isChecked());
+
+    d->m_currentState.setIncludingTransfers(d->m_tabRowColQuery->ui->m_checkTransfers->isChecked());
   }
 
   if (d->m_tabChart) {
     eMyMoney::Report::ChartType ct[5] = { eMyMoney::Report::ChartType::Line, eMyMoney::Report::ChartType::Bar, eMyMoney::Report::ChartType::StackedBar, eMyMoney::Report::ChartType::Pie, eMyMoney::Report::ChartType::Ring };
+    eMyMoney::Report::ChartPalette cp[4] = { eMyMoney::Report::ChartPalette::Application, eMyMoney::Report::ChartPalette::Default, eMyMoney::Report::ChartPalette::Rainbow, eMyMoney::Report::ChartPalette::Subdued };
     d->m_currentState.setChartType(ct[d->m_tabChart->ui->m_comboType->currentIndex()]);
-
+    d->m_currentState.setChartPalette(cp[d->m_tabChart->ui->m_comboPalette->currentIndex()]);
     d->m_currentState.setChartCHGridLines(d->m_tabChart->ui->m_checkCHGridLines->isChecked());
     d->m_currentState.setChartSVGridLines(d->m_tabChart->ui->m_checkSVGridLines->isChecked());
     d->m_currentState.setChartDataLabels(d->m_tabChart->ui->m_checkValues->isChecked());
     d->m_currentState.setChartByDefault(d->m_tabChart->ui->m_checkShowChart->isChecked());
     d->m_currentState.setChartLineWidth(d->m_tabChart->ui->m_lineWidth->value());
     d->m_currentState.setLogYAxis(d->m_tabChart->ui->m_logYaxis->isChecked());
+    d->m_currentState.setNegExpenses(d->m_tabChart->ui->m_negExpenses->isChecked());
   }
 
   if (d->m_tabRange) {
@@ -388,6 +394,12 @@ void KReportConfigurationFilterDlg::slotLogAxisChanged(int state)
     d->m_tabRange->setRangeLogarythmic(false);
 }
 
+void KReportConfigurationFilterDlg::slotNegExpensesChanged(int state)
+{
+  Q_D(KReportConfigurationFilterDlg);
+  d->m_tabChart->setNegExpenses(state == Qt::Checked);
+}
+
 void KReportConfigurationFilterDlg::slotReset()
 {
   Q_D(KReportConfigurationFilterDlg);
@@ -530,6 +542,7 @@ void KReportConfigurationFilterDlg::slotReset()
 
     d->m_tabRowColQuery->ui->m_checkHideSplitDetails->setChecked
     (d->m_initialState.detailLevel() == eMyMoney::Report::DetailLevel::None || d->m_initialState.isHideTransactions());
+    d->m_tabRowColQuery->ui->m_checkTransfers->setChecked(d->m_initialState.isIncludingTransfers());
   }
 
   if (d->m_tabChart) {
@@ -548,12 +561,24 @@ void KReportConfigurationFilterDlg::slotReset()
       default:
         throw MYMONEYEXCEPTION_CSTRING("KReportConfigurationFilterDlg::slotReset(): Report has invalid charttype");
     }
+    combo = d->m_tabChart->ui->m_comboPalette;
+    switch (d->m_initialState.chartPalette()) {
+      case eMyMoney::Report::ChartPalette::Application:
+      case eMyMoney::Report::ChartPalette::Default:
+      case eMyMoney::Report::ChartPalette::Rainbow:
+      case eMyMoney::Report::ChartPalette::Subdued:
+        combo->setCurrentItem(static_cast<int>(d->m_initialState.chartPalette()));
+        break;
+      default:
+        throw MYMONEYEXCEPTION_CSTRING("KReportConfigurationFilterDlg::slotReset(): Report has invalid chartpalette");
+    }
     d->m_tabChart->ui->m_checkCHGridLines->setChecked(d->m_initialState.isChartCHGridLines());
     d->m_tabChart->ui->m_checkSVGridLines->setChecked(d->m_initialState.isChartSVGridLines());
     d->m_tabChart->ui->m_checkValues->setChecked(d->m_initialState.isChartDataLabels());
     d->m_tabChart->ui->m_checkShowChart->setChecked(d->m_initialState.isChartByDefault());
     d->m_tabChart->ui->m_lineWidth->setValue(d->m_initialState.chartLineWidth());
     d->m_tabChart->ui->m_logYaxis->setChecked(d->m_initialState.isLogYAxis());
+    d->m_tabChart->ui->m_negExpenses->setChecked(d->m_initialState.isNegExpenses());
   }
 
   if (d->m_tabRange) {
