@@ -60,7 +60,7 @@ ReportsView::~ReportsView()
 void ReportsView::plug()
 {
   m_view = new KReportsView;
-  viewInterface()->addView(m_view, i18n("Reports"), View::Reports);
+  viewInterface()->addView(m_view, i18n("Reports"), View::Reports, Icons::Icon::Reports);
 }
 
 void ReportsView::unplug()
@@ -157,15 +157,20 @@ QString ReportsView::budget() const
   const auto file = MyMoneyFile::instance();
 
   QString html;
+  //div header
+  html += "<div class=\"shadow\"><div class=\"displayblock\"><div class=\"summaryheader\">" + i18n("Budget") + "</div>\n<div class=\"gap\">&nbsp;</div>\n";
+
   if (file->countBudgets() == 0) {
+    html += "<table width=\"100%\" cellspacing=\"0\" cellpadding=\"2\" class=\"summarytable\" >";
     html += QString("<tr>");
     html += QString("<td><center>%1</center></td>").arg(i18n("You have no budgets to display."));
     html += QString("</tr>");
+    html += "</table></div></div>";
     return html;
   }
 
   auto prec = MyMoneyMoney::denomToPrec(file->baseCurrency().smallestAccountFraction());
-  auto isOverrun = false;
+  bool isOverrun = false;
   int i = 0;
 
   //config report just like "Monthly Budgeted vs Actual
@@ -183,9 +188,6 @@ QString ReportsView::budget() const
 
   reports::PivotGrid grid = table.grid();
 
-  //div header
-  html += "<div class=\"shadow\"><div class=\"displayblock\"><div class=\"summaryheader\">" + i18n("Budget") + "</div>\n<div class=\"gap\">&nbsp;</div>\n";
-
   //display budget summary
   html += "<table width=\"100%\" cellspacing=\"0\" cellpadding=\"2\" class=\"summarytable\" >";
   html += "<tr class=\"itemtitle\">";
@@ -241,6 +243,7 @@ QString ReportsView::budget() const
   html += "</td></tr>";
 
   reports::PivotGrid::iterator it_outergroup = grid.begin();
+  const int column = 0;
   while (it_outergroup != grid.end()) {
     i = 0;
     reports::PivotOuterGroup::iterator it_innergroup = (*it_outergroup).begin();
@@ -248,7 +251,7 @@ QString ReportsView::budget() const
       reports::PivotInnerGroup::iterator it_row = (*it_innergroup).begin();
       while (it_row != (*it_innergroup).end()) {
         //column number is 1 because the report includes only current month
-        if (it_row.value()[reports::eBudgetDiff].value(1).isNegative()) {
+        if (it_row.value()[reports::eBudgetDiff].value(column).isNegative()) {
           //get report account to get the name later
           reports::ReportAccount rowname = it_row.key();
 
@@ -261,9 +264,9 @@ QString ReportsView::budget() const
           html += QString("<tr class=\"row-%1\">").arg(i++ & 0x01 ? "even" : "odd");
 
           //get values from grid
-          MyMoneyMoney actualValue = it_row.value()[reports::eActual][1];
-          MyMoneyMoney budgetValue = it_row.value()[reports::eBudget][1];
-          MyMoneyMoney budgetDiffValue = it_row.value()[reports::eBudgetDiff][1];
+          MyMoneyMoney actualValue = it_row.value()[reports::eActual][column];
+          MyMoneyMoney budgetValue = it_row.value()[reports::eBudget][column];
+          MyMoneyMoney budgetDiffValue = it_row.value()[reports::eBudgetDiff][column];
 
           //format amounts
           QString actualAmount = actualValue.formatMoney(file->baseCurrency().tradingSymbol(), prec);
@@ -290,7 +293,7 @@ QString ReportsView::budget() const
   }
 
   //if no negative differences are found, then inform that
-  if (!isOverrun) {
+  if (isOverrun == false) {
     html += QString::fromLatin1("<tr class=\"row-%1\" style=\"font-weight:bold;\">").arg(((i++ & 1) == 1) ? QLatin1String("even") : QLatin1String("odd"));
     html += QString::fromLatin1("<td class=\"center\" colspan=\"4\">%1</td>").arg(i18n("No Budget Categories have been overrun"));
     html += "</tr>";
