@@ -3,6 +3,8 @@
  * Copyright 2006       Darren Gould <darren_gould@gmx.de>
  * Copyright 2007-2010  Alvaro Soliverez <asoliverez@gmail.com>
  * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ * Copyright 2018       Michael Kiefer <Michael-Kiefer@web.de>
+ * Copyright 2019       Thomas Baumgart <tbaumgart@kde.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -54,7 +56,8 @@ namespace Element {
     Amount,
     Dates,
     Category,
-    AccountGroup
+    AccountGroup,
+    Validity
   };
 
   enum class Budget {
@@ -85,6 +88,8 @@ namespace Attribute {
     SettlementPeriod, ShowSTLTCapitalGains, TermsSeparator,
     Pattern, CaseSensitive, RegEx, InvertText, State,
     From, To,
+    NegExpenses,
+    Validity, ChartPalette,
     // insert new entries above this line
     LastAttribute
   };
@@ -134,7 +139,8 @@ namespace MyMoneyXmlContentHandler2 {
       {Element::Report::Amount,       QStringLiteral("AMOUNT")},
       {Element::Report::Dates,        QStringLiteral("DATES")},
       {Element::Report::Category,     QStringLiteral("CATEGORY")},
-      {Element::Report::AccountGroup, QStringLiteral("ACCOUNTGROUP")}
+      {Element::Report::AccountGroup, QStringLiteral("ACCOUNTGROUP")},
+      {Element::Report::Validity,     QStringLiteral("VALIDITY")}
     };
     return elementNames.value(elementID);
   }
@@ -169,6 +175,7 @@ namespace MyMoneyXmlContentHandler2 {
       {Attribute::Report::Detail,                 QStringLiteral("detail")},
       {Attribute::Report::ColumnsAreDays,         QStringLiteral("columnsaredays")},
       {Attribute::Report::ChartType,              QStringLiteral("charttype")},
+      {Attribute::Report::ChartPalette,           QStringLiteral("chartpalette")},
       {Attribute::Report::ChartCHGridLines,       QStringLiteral("chartchgridlines")},
       {Attribute::Report::ChartSVGridLines,       QStringLiteral("chartsvgridlines")},
       {Attribute::Report::ChartDataLabels,        QStringLiteral("chartdatalabels")},
@@ -196,11 +203,15 @@ namespace MyMoneyXmlContentHandler2 {
       {Attribute::Report::InvertText,             QStringLiteral("inverttext")},
       {Attribute::Report::State,                  QStringLiteral("state")},
       {Attribute::Report::From,                   QStringLiteral("from")},
-      {Attribute::Report::To,                     QStringLiteral("to")}
+      {Attribute::Report::To,                     QStringLiteral("to")},
+      {Attribute::Report::Validity,               QStringLiteral("validity")},
+      {Attribute::Report::NegExpenses,            QStringLiteral("negexpenses")}
     };
     return attributeNames.value(attributeID);
   }
 
+  uint qHash(const Attribute::Report key, uint seed) { Q_UNUSED(seed); return ::qHash(static_cast<uint>(key), 0); }
+
   QString elementName(Element::Budget elementID)
   {
     static const QMap<Element::Budget, QString> elementNames {
@@ -225,6 +236,8 @@ namespace MyMoneyXmlContentHandler2 {
     return attributeNames.value(attributeID);
   }
 
+  uint qHash(const Attribute::Budget key, uint seed) { Q_UNUSED(seed); return ::qHash(static_cast<uint>(key), 0); }
+
   QHash<eMyMoney::Report::RowType, QString> rowTypesLUT()
   {
     static const QHash<eMyMoney::Report::RowType, QString> lut {
@@ -394,6 +407,48 @@ namespace MyMoneyXmlContentHandler2 {
     return typeAttributeLUT().key(text, 4);
   }
 
+  QHash<eMyMoney::Report::ChartPalette, QString> chartPaletteLUT()
+  {
+    static const QHash<eMyMoney::Report::ChartPalette, QString> lut {
+      {eMyMoney::Report::ChartPalette::Application, QStringLiteral("application")},
+      {eMyMoney::Report::ChartPalette::Default,     QStringLiteral("default")},
+      {eMyMoney::Report::ChartPalette::Rainbow,     QStringLiteral("rainbow")},
+      {eMyMoney::Report::ChartPalette::Subdued,     QStringLiteral("subdued")},
+    };
+    return lut;
+  }
+
+  QString reportNames(eMyMoney::Report::ChartPalette textID)
+  {
+    return chartPaletteLUT().value(textID);
+  }
+
+  eMyMoney::Report::ChartPalette stringToChartPalette(const QString &text)
+  {
+    return chartPaletteLUT().key(text, eMyMoney::Report::ChartPalette::End);
+  }
+
+  QHash<int, QString> paletteAttributeLUT()
+  {
+    static const QHash<int, QString> lut {
+      {0, QStringLiteral("application")},
+      {1, QStringLiteral("default")},
+      {2, QStringLiteral("rainbow")},
+      {3, QStringLiteral("subdued")},
+    };
+    return lut;
+  }
+
+  QString paletteAttributeToString(int textID)
+  {
+    return paletteAttributeLUT().value(textID);
+  }
+
+  int stringToPaletteAttribute(const QString &text)
+  {
+    return paletteAttributeLUT().key(text, 4);
+  }
+
   QHash<int, QString> stateAttributeLUT()
   {
     static const QHash<int, QString> lut {
@@ -417,6 +472,26 @@ namespace MyMoneyXmlContentHandler2 {
     return stateAttributeLUT().key(text, 5);
   }
 
+  QHash<int, QString> validityAttributeLUT()
+  {
+    static const QHash<int, QString> lut {
+      {0, QStringLiteral("any")},
+      {1, QStringLiteral("valid")},
+      {2, QStringLiteral("invalid")},
+    };
+    return lut;
+  }
+
+  QString validityAttributeToString(int textID)
+  {
+    return validityAttributeLUT().value(textID);
+  }
+
+  int stringToValidityAttribute(const QString &text)
+  {
+    return validityAttributeLUT().key(text, 0);
+  }
+
   QHash<eMyMoney::TransactionFilter::Date, QString> dateLockLUT()
   {
     static const QHash<eMyMoney::TransactionFilter::Date, QString> lut {
@@ -649,7 +724,7 @@ namespace MyMoneyXmlContentHandler2 {
 
         // read rows/columns tab
         if (node.hasAttribute(attributeName(Attribute::Report::Budget)))
-          report.setBudget(node.attribute(attributeName(Attribute::Report::Budget)));
+          report.setBudget(node.attribute(attributeName(Attribute::Report::Budget)), report.isIncludingBudgetActuals());
 
         if (rowTypeFromXML != eMyMoney::Report::RowType::Invalid)
           report.setRowType(rowTypeFromXML);
@@ -684,11 +759,18 @@ namespace MyMoneyXmlContentHandler2 {
         else
           report.setChartType(eMyMoney::Report::ChartType::None);
 
+        const auto chartPaletteFromXML = stringToChartPalette(node.attribute(attributeName(Attribute::Report::ChartPalette)));
+        if (chartPaletteFromXML != eMyMoney::Report::ChartPalette::End)
+          report.setChartPalette(chartPaletteFromXML);
+        else
+          report.setChartPalette(eMyMoney::Report::ChartPalette::Application);
+
         report.setChartCHGridLines(node.attribute(attributeName(Attribute::Report::ChartCHGridLines), "1").toUInt());
         report.setChartSVGridLines(node.attribute(attributeName(Attribute::Report::ChartSVGridLines), "1").toUInt());
         report.setChartDataLabels(node.attribute(attributeName(Attribute::Report::ChartDataLabels), "1").toUInt());
         report.setChartByDefault(node.attribute(attributeName(Attribute::Report::ChartByDefault), "0").toUInt());
         report.setLogYAxis(node.attribute(attributeName(Attribute::Report::LogYAxis), "0").toUInt());
+        report.setNegExpenses(node.attribute(attributeName(Attribute::Report::NegExpenses), "0").toUInt());
         report.setChartLineWidth(node.attribute(attributeName(Attribute::Report::ChartLineWidth), QString(MyMoneyReport::lineWidth())).toUInt());
 
         // read range tab
@@ -730,6 +812,7 @@ namespace MyMoneyXmlContentHandler2 {
         report.setLoansOnly(node.attribute(attributeName(Attribute::Report::Loans), "0").toUInt());
         report.setHideTransactions(node.attribute(attributeName(Attribute::Report::HideTransactions), "0").toUInt());
         report.setShowingColumnTotals(node.attribute(attributeName(Attribute::Report::ShowColumnTotals), "1").toUInt());
+        report.setIncludingTransfers(node.attribute(attributeName(Attribute::Report::IncludesTransfers), "0").toUInt());
         const auto detailLevelFromXML = stringToDetailLevel(node.attribute(attributeName(Attribute::Report::Detail), "none"));
         if (detailLevelFromXML == eMyMoney::Report::DetailLevel::All)
           report.setDetailLevel(detailLevelFromXML);
@@ -782,6 +865,11 @@ namespace MyMoneyXmlContentHandler2 {
           if (state != -1)
             report.addState(state);
         }
+        if (elementName(Element::Report::Validity) == c.tagName() && c.hasAttribute(attributeName(Attribute::Report::Validity))) {
+          const auto validity = stringToValidityAttribute(c.attribute(attributeName(Attribute::Report::Validity)));
+          if (validity != -1)
+            report.addValidity(validity);
+        }
         if (elementName(Element::Report::Number) == c.tagName())
           report.setNumberFilter(c.attribute(attributeName(Attribute::Report::From)), c.attribute(attributeName(Attribute::Report::To)));
         if (elementName(Element::Report::Amount) == c.tagName())
@@ -832,7 +920,7 @@ namespace MyMoneyXmlContentHandler2 {
       if (report.reportType() == eMyMoney::Report::ReportType::PivotTable)
         el.setAttribute(attributeName(Attribute::Report::Type), "pivottable 1.15");
       else if (report.reportType() == eMyMoney::Report::ReportType::QueryTable)
-        el.setAttribute(attributeName(Attribute::Report::Type), "querytable 1.14");
+        el.setAttribute(attributeName(Attribute::Report::Type), "querytable 1.15");
       else if (report.reportType() == eMyMoney::Report::ReportType::InfoTable)
         el.setAttribute(attributeName(Attribute::Report::Type), "infotable 1.0");
 
@@ -840,14 +928,9 @@ namespace MyMoneyXmlContentHandler2 {
       el.setAttribute(attributeName(Attribute::Report::ID), report.id());
 
       // write general tab
-      auto anonymous = false;
-      if (anonymous) {
-        el.setAttribute(attributeName(Attribute::Report::Name), report.id());
-        el.setAttribute(attributeName(Attribute::Report::Comment), QString(report.comment()).fill('x'));
-      } else {
-        el.setAttribute(attributeName(Attribute::Report::Name), report.name());
-        el.setAttribute(attributeName(Attribute::Report::Comment), report.comment());
-      }
+      el.setAttribute(attributeName(Attribute::Report::Name), report.name());
+      el.setAttribute(attributeName(Attribute::Report::Comment), report.comment());
+
       el.setAttribute(attributeName(Attribute::Report::ConvertCurrency), report.isConvertCurrency());
       el.setAttribute(attributeName(Attribute::Report::Favorite), report.isFavorite());
       el.setAttribute(attributeName(Attribute::Report::SkipZero), report.isSkippingZero());
@@ -881,11 +964,13 @@ namespace MyMoneyXmlContentHandler2 {
         el.setAttribute(attributeName(Attribute::Report::IncludesUnused), report.isIncludingUnusedAccounts());
         el.setAttribute(attributeName(Attribute::Report::ColumnsAreDays), report.isColumnsAreDays());
         el.setAttribute(attributeName(Attribute::Report::ChartType), reportNames(report.chartType()));
+        el.setAttribute(attributeName(Attribute::Report::ChartPalette), reportNames(report.chartPalette()));
         el.setAttribute(attributeName(Attribute::Report::ChartCHGridLines), report.isChartCHGridLines());
         el.setAttribute(attributeName(Attribute::Report::ChartSVGridLines), report.isChartSVGridLines());
         el.setAttribute(attributeName(Attribute::Report::ChartDataLabels), report.isChartDataLabels());
         el.setAttribute(attributeName(Attribute::Report::ChartByDefault), report.isChartByDefault());
         el.setAttribute(attributeName(Attribute::Report::LogYAxis), report.isLogYAxis());
+        el.setAttribute(attributeName(Attribute::Report::NegExpenses), report.isNegExpenses());
         el.setAttribute(attributeName(Attribute::Report::ChartLineWidth), report.chartLineWidth());
         el.setAttribute(attributeName(Attribute::Report::ColumnType), reportNames(report.columnType()));
         el.setAttribute(attributeName(Attribute::Report::DataLock), reportNames(report.dataFilter()));
@@ -915,6 +1000,7 @@ namespace MyMoneyXmlContentHandler2 {
         el.setAttribute(attributeName(Attribute::Report::HideTransactions), report.isHideTransactions());
         el.setAttribute(attributeName(Attribute::Report::ShowColumnTotals), report.isShowingColumnTotals());
         el.setAttribute(attributeName(Attribute::Report::Detail), reportNames(report.detailLevel()));
+        el.setAttribute(attributeName(Attribute::Report::IncludesTransfers), report.isIncludingTransfers());
 
         // write performance tab
         if (report.queryColumns() & eMyMoney::Report::QueryColumn::Performance || report.queryColumns() & eMyMoney::Report::QueryColumn::CapitalGain)
@@ -973,6 +1059,20 @@ namespace MyMoneyXmlContentHandler2 {
           ++it_state;
         }
       }
+
+      QList<int> validitylist;
+      if (report.validities(validitylist) && ! validitylist.empty()) {
+        // iterate over payees, and add each one
+        QList<int>::const_iterator it_validity = validitylist.constBegin();
+        while (it_validity != validitylist.constEnd()) {
+          QDomElement p = document.createElement(elementName(Element::Report::Validity));
+          p.setAttribute(attributeName(Attribute::Report::Validity), validityAttributeToString(*it_validity));
+          el.appendChild(p);
+
+          ++it_validity;
+        }
+      }
+
       //
       // Number Filter
       //
