@@ -76,33 +76,33 @@ QDate KGlobalLedgerViewPrivate::m_lastPostDate;
 KGlobalLedgerView::KGlobalLedgerView(QWidget *parent) :
   KMyMoneyViewBase(*new KGlobalLedgerViewPrivate(this), parent)
 {
-  typedef void(KGlobalLedgerView::*KGlobalLedgerViewFunc)();
-  const QHash<Action, KGlobalLedgerViewFunc> actionConnections {
-    {Action::NewTransaction,            &KGlobalLedgerView::slotNewTransaction},
-    {Action::EditTransaction,           &KGlobalLedgerView::slotEditTransaction},
-    {Action::DeleteTransaction,         &KGlobalLedgerView::slotDeleteTransaction},
-    {Action::DuplicateTransaction,      &KGlobalLedgerView::slotDuplicateTransaction},
-    {Action::EnterTransaction,          &KGlobalLedgerView::slotEnterTransaction},
-    {Action::AcceptTransaction,         &KGlobalLedgerView::slotAcceptTransaction},
-    {Action::CancelTransaction,         &KGlobalLedgerView::slotCancelTransaction},
-    {Action::EditSplits,                &KGlobalLedgerView::slotEditSplits},
-    {Action::CopySplits,                &KGlobalLedgerView::slotCopySplits},
-    {Action::GoToPayee,                 &KGlobalLedgerView::slotGoToPayee},
-    {Action::GoToAccount,               &KGlobalLedgerView::slotGoToAccount},
-    {Action::MatchTransaction,          &KGlobalLedgerView::slotMatchTransactions},
-    {Action::CombineTransactions,       &KGlobalLedgerView::slotCombineTransactions},
-    {Action::ToggleReconciliationFlag,  &KGlobalLedgerView::slotToggleReconciliationFlag},
-    {Action::MarkCleared,               &KGlobalLedgerView::slotMarkCleared},
-    {Action::MarkReconciled,            &KGlobalLedgerView::slotMarkReconciled},
-    {Action::MarkNotReconciled,         &KGlobalLedgerView::slotMarkNotReconciled},
-    {Action::SelectAllTransactions,     &KGlobalLedgerView::slotSelectAllTransactions},
-    {Action::NewScheduledTransaction,   &KGlobalLedgerView::slotCreateScheduledTransaction},
-    {Action::AssignTransactionsNumber,  &KGlobalLedgerView::slotAssignNumber},
-    {Action::StartReconciliation,       &KGlobalLedgerView::slotStartReconciliation},
-    {Action::FinishReconciliation,      &KGlobalLedgerView::slotFinishReconciliation},
-    {Action::PostponeReconciliation,    &KGlobalLedgerView::slotPostponeReconciliation},
-    {Action::OpenAccount,               &KGlobalLedgerView::slotOpenAccount},
-    {Action::EditFindTransaction,       &KGlobalLedgerView::slotFindTransaction},
+  const QHash<Action, std::function<void()>> actionConnections {
+    {Action::NewTransaction,            [this](){ KGlobalLedgerView::slotNewTransaction(); }},
+    {Action::EditTransaction,           [this](){ KGlobalLedgerView::slotEditTransaction(); }},
+    {Action::DeleteTransaction,         [this](){ KGlobalLedgerView::slotDeleteTransaction(); }},
+    {Action::DuplicateTransaction,      [this](){ KGlobalLedgerView::slotDuplicateTransaction(); }},
+    {Action::AddReversingTransaction,   [this](){ KGlobalLedgerView::slotDuplicateTransaction(true); }},
+    {Action::EnterTransaction,          [this](){ KGlobalLedgerView::slotEnterTransaction(); }},
+    {Action::AcceptTransaction,         [this](){ KGlobalLedgerView::slotAcceptTransaction(); }},
+    {Action::CancelTransaction,         [this](){ KGlobalLedgerView::slotCancelTransaction(); }},
+    {Action::EditSplits,                [this](){ KGlobalLedgerView::slotEditSplits(); }},
+    {Action::CopySplits,                [this](){ KGlobalLedgerView::slotCopySplits(); }},
+    {Action::GoToPayee,                 [this](){ KGlobalLedgerView::slotGoToPayee(); }},
+    {Action::GoToAccount,               [this](){ KGlobalLedgerView::slotGoToAccount(); }},
+    {Action::MatchTransaction,          [this](){ KGlobalLedgerView::slotMatchTransactions(); }},
+    {Action::CombineTransactions,       [this](){ KGlobalLedgerView::slotCombineTransactions(); }},
+    {Action::ToggleReconciliationFlag,  [this](){ KGlobalLedgerView::slotToggleReconciliationFlag(); }},
+    {Action::MarkCleared,               [this](){ KGlobalLedgerView::slotMarkCleared(); }},
+    {Action::MarkReconciled,            [this](){ KGlobalLedgerView::slotMarkReconciled(); }},
+    {Action::MarkNotReconciled,         [this](){ KGlobalLedgerView::slotMarkNotReconciled(); }},
+    {Action::SelectAllTransactions,     [this](){ KGlobalLedgerView::slotSelectAllTransactions(); }},
+    {Action::NewScheduledTransaction,   [this](){ KGlobalLedgerView::slotCreateScheduledTransaction(); }},
+    {Action::AssignTransactionsNumber,  [this](){ KGlobalLedgerView::slotAssignNumber(); }},
+    {Action::StartReconciliation,       [this](){ KGlobalLedgerView::slotStartReconciliation(); }},
+    {Action::FinishReconciliation,      [this](){ KGlobalLedgerView::slotFinishReconciliation(); }},
+    {Action::PostponeReconciliation,    [this](){ KGlobalLedgerView::slotPostponeReconciliation(); }},
+    {Action::OpenAccount,               [this](){ KGlobalLedgerView::slotOpenAccount(); }},
+    {Action::EditFindTransaction,       [this](){ KGlobalLedgerView::slotFindTransaction(); }},
   };
 
   for (auto a = actionConnections.cbegin(); a != actionConnections.cend(); ++a)
@@ -288,7 +288,7 @@ void KGlobalLedgerView::updateLedgerActionsInternal()
   const QVector<Action> actionsToBeDisabled {
     Action::EditTransaction, Action::EditSplits, Action::EnterTransaction,
     Action::CancelTransaction, Action::DeleteTransaction, Action::MatchTransaction,
-    Action::AcceptTransaction, Action::DuplicateTransaction, Action::ToggleReconciliationFlag, Action::MarkCleared,
+    Action::AcceptTransaction, Action::DuplicateTransaction, Action::AddReversingTransaction, Action::ToggleReconciliationFlag, Action::MarkCleared,
     Action::GoToAccount, Action::GoToPayee, Action::AssignTransactionsNumber, Action::NewScheduledTransaction,
     Action::CombineTransactions, Action::CopySplits,
   };
@@ -320,6 +320,10 @@ void KGlobalLedgerView::updateLedgerActionsInternal()
       pActions[Action::DuplicateTransaction]->setEnabled(canDuplicateTransactions(d->m_selectedTransactions, tooltip) && !d->m_selectedTransactions[0].transaction().id().isEmpty());
       pActions[Action::DuplicateTransaction]->setToolTip(tooltip);
 
+      tooltip = i18n("Add reversing transactions to the currently selected");
+      pActions[Action::AddReversingTransaction]->setEnabled(canDuplicateTransactions(d->m_selectedTransactions, tooltip) && !d->m_selectedTransactions[0].transaction().id().isEmpty());
+      pActions[Action::AddReversingTransaction]->setToolTip(tooltip);
+
       if (canEditTransactions(d->m_selectedTransactions, tooltip)) {
         pActions[Action::EditTransaction]->setEnabled(true);
         // editing splits is allowed only if we have one transaction selected
@@ -444,7 +448,7 @@ void KGlobalLedgerView::slotUpdateSummaryLine(const KMyMoneyRegister::SelectedTr
         balance += t.split().shares();
       }
     }
-    d->m_rightSummaryLabel->setText(QString("%1: %2").arg(QChar(0x2211), balance.formatMoney("", d->m_precision)));
+    d->m_rightSummaryLabel->setText(QString("%1: %2").arg(QChar(0x2211), balance.formatMoney("", -1)));
 
   } else {
     if (d->isReconciliationAccount()) {
@@ -510,7 +514,7 @@ void KGlobalLedgerView::slotSetReconcileAccount(const MyMoneyAccount& acc, const
       d->m_buttonbar->addAction(pActions[Action::FinishReconciliation]);
       // when we start reconciliation, we need to reload the view
       // because no data has been changed. When postponing or finishing
-      // reconciliation, the data change in the engine takes care of updateing
+      // reconciliation, the data change in the engine takes care of updating
       // the view.
       refresh();
     }
@@ -1015,7 +1019,7 @@ bool KGlobalLedgerView::focusNextPrevChild(bool next)
 
         if (((w->focusPolicy() & Qt::TabFocus) == Qt::TabFocus) && w->isVisible() && w->isEnabled()) {
           // qDebug() << "Set focus to" << w->objectName();
-          w->setFocus();
+          w->setFocus(next ? Qt::TabFocusReason: Qt::BacktabFocusReason);
           rc = true;
           break;
         }
@@ -1264,26 +1268,24 @@ void KGlobalLedgerView::slotMoveToAccount(const QString& id)
     pMenus[Menu::Transaction]->close();
 
   if (!d->m_selectedTransactions.isEmpty()) {
+    const auto file = MyMoneyFile::instance();
     MyMoneyFileTransaction ft;
     try {
       foreach (const auto selection, d->m_selectedTransactions) {
         if (d->m_currentAccount.accountType() == eMyMoney::Account::Type::Investment) {
           d->moveInvestmentTransaction(d->m_currentAccount.id(), id, selection.transaction());
         } else {
-          auto changed = false;
-          auto t = selection.transaction();
-
-          foreach (const auto split, selection.transaction().splits()) {
-            if (split.accountId() == d->m_currentAccount.id()) {
-              MyMoneySplit s = split;
-              s.setAccountId(id);
-              t.modifySplit(s);
-              changed = true;
-            }
-          }
-          if (changed) {
-            MyMoneyFile::instance()->modifyTransaction(t);
-          }
+          // we get the data afresh from the engine as
+          // it might have changed by a previous iteration
+          // in this loop. Use case: two splits point to
+          // the same account and both are selected.
+          auto tid = selection.transaction().id();
+          auto sid = selection.split().id();
+          auto t = file->transaction(tid);
+          auto s = t.splitById(sid);
+          s.setAccountId(id);
+          t.modifySplit(s);
+          file->modifyTransaction(t);
         }
       }
       ft.commit();
@@ -1327,10 +1329,9 @@ void KGlobalLedgerView::slotUpdateMoveToAccountMenu()
 
     accountSet.load(d->m_moveToAccountSelector);
     // remove those accounts that we currently reference
+    // with the selected items
     foreach (const auto selection, d->m_selectedTransactions) {
-      foreach (const auto split, selection.transaction().splits()) {
-        d->m_moveToAccountSelector->removeItem(split.accountId());
-      }
+      d->m_moveToAccountSelector->removeItem(selection.split().accountId());
     }
     // remove those accounts from the list that are denominated
     // in a different currency
@@ -1517,7 +1518,7 @@ void KGlobalLedgerView::slotDeleteTransaction()
   }
 }
 
-void KGlobalLedgerView::slotDuplicateTransaction()
+void KGlobalLedgerView::slotDuplicateTransaction(bool reverse)
 {
   Q_D(KGlobalLedgerView);
   // since we may jump here via code, we have to make sure to react only
@@ -1544,8 +1545,13 @@ void KGlobalLedgerView::slotDuplicateTransaction()
         // clear invalid data
         t.setEntryDate(QDate());
         t.clearId();
-        // and set the post date to today
-        t.setPostDate(QDate::currentDate());
+
+        if (reverse)
+            // reverse transaction
+            t.reverse();
+        else
+            // set the post date to today
+            t.setPostDate(QDate::currentDate());
 
         MyMoneyFile::instance()->addTransaction(t);
         lt = t;
@@ -1705,20 +1711,20 @@ void KGlobalLedgerView::slotCopyTransactionToClipboard()
     try {
       const auto& s = st.split();
       // Date
-      txt += i18n("Date: %1").arg(st.transaction().postDate().toString(Qt::DefaultLocaleShortDate));
+      txt += i18n("Date: %1", st.transaction().postDate().toString(Qt::DefaultLocaleShortDate));
       txt += QStringLiteral("\n");
       // Payee
       QString payee = i18nc("Name for unknown payee", "Unknown");
       if (!s.payeeId().isEmpty()) {
         payee = file->payee(s.payeeId()).name();
       }
-      txt += i18n("Payee: %1").arg(payee);
+      txt += i18n("Payee: %1", payee);
       txt += QStringLiteral("\n");
       // Amount
-      txt += i18n("Amount: %1").arg(s.value().formatMoney(currency.tradingSymbol(),  MyMoneyMoney::denomToPrec(acc.fraction(currency))));
+      txt += i18n("Amount: %1", s.value().formatMoney(currency.tradingSymbol(),  MyMoneyMoney::denomToPrec(acc.fraction(currency))));
       txt += QStringLiteral("\n");
       // Memo
-      txt += i18n("Memo: %1").arg(s.memo());
+      txt += i18n("Memo: %1", s.memo());
       txt += QStringLiteral("\n");
 
     } catch (MyMoneyException &) {
@@ -1953,10 +1959,12 @@ void KGlobalLedgerView::slotStartReconciliation()
   Q_D(KGlobalLedgerView);
 
   // we cannot reconcile standard accounts
-  if (!MyMoneyFile::instance()->isStandardAccount(d->m_currentAccount.id()))
+  if (!MyMoneyFile::instance()->isStandardAccount(d->m_currentAccount.id())) {
+    emit selectByObject(d->m_currentAccount, eView::Intent::SynchronizeAccountInLedgersView);
     emit selectByObject(d->m_currentAccount, eView::Intent::StartEnteringOverdueScheduledTransactions);
-  // asynchronous call to KScheduledView::slotEnterOverdueSchedules is made here
-  // after that all activity should be continued in KGlobalLedgerView::slotContinueReconciliation()
+    // asynchronous call to KScheduledView::slotEnterOverdueSchedules is made here
+    // after that all activity should be continued in KGlobalLedgerView::slotContinueReconciliation()
+  }
 }
 
 void KGlobalLedgerView::slotFinishReconciliation()
