@@ -57,6 +57,7 @@ public:
 protected:
   void showEvent(QShowEvent* event) override;
   void wheelEvent(QWheelEvent *event) override;
+  bool eventFilter(QObject* o, QEvent* e) override;
 
 public Q_SLOTS:
   /**
@@ -69,6 +70,7 @@ private:
 
 private Q_SLOTS:
   void slotOpenUrl(const QUrl &url);
+  void slotAdjustScrollPos();
 };
 
 #endif
