@@ -76,6 +76,22 @@ void KInvestmentView::setDefaultFocus()
   }
 }
 
+void KInvestmentView::executeCustomAction(eView::Action action)
+{
+  switch(action) {
+    case eView::Action::Refresh:
+      refresh();
+      break;
+
+    case eView::Action::SetDefaultFocus:
+      setDefaultFocus();
+      break;
+
+    default:
+      break;
+  }
+}
+
 void KInvestmentView::refresh()
 {
   Q_D(KInvestmentView);
@@ -90,7 +106,7 @@ void KInvestmentView::showEvent(QShowEvent* event)
   if (d->m_needLoad)
     d->init();
 
-  emit aboutToShow(View::Investments);
+  emit customActionRequested(View::Investments, eView::Action::AboutToShow);
 
   d->m_needReload[eView::Investment::Tab::Equities] = true;  // ensure tree view will be reloaded after selecting account in ledger view
   if (d->m_needReload[eView::Investment::Tab::Equities] == true ||
@@ -111,13 +127,13 @@ void KInvestmentView::updateActions(const MyMoneyObject& obj)
   const auto& acc = static_cast<const MyMoneyAccount&>(obj);
 
   const auto file = MyMoneyFile::instance();
-  if (!d->m_idInvAcc.isEmpty()) {
-    const auto account = file->account(d->m_idInvAcc);
-    auto b = account.accountType() == eMyMoney::Account::Type::Investment ? true : false;
-    pActions[eMenu::Action::NewInvestment]->setEnabled(b);
-  }
+  auto b = acc.accountType() == eMyMoney::Account::Type::Investment ? true : false;
+  if (isVisible() && !d->m_idInvAcc.isEmpty())
+    b = true;
 
-  auto b = acc.isInvest() ? true : false;
+  pActions[eMenu::Action::NewInvestment]->setEnabled(b);
+
+  b = acc.isInvest() ? true : false;
   pActions[eMenu::Action::EditInvestment]->setEnabled(b);
   pActions[eMenu::Action::DeleteInvestment]->setEnabled(b && !file->isReferenced(acc));
   pActions[eMenu::Action::UpdatePriceManually]->setEnabled(b);
@@ -156,7 +172,7 @@ void KInvestmentView::slotEquitySelected(const QModelIndex &current, const QMode
   Q_D(KInvestmentView);
   Q_UNUSED(current);
   Q_UNUSED(previous);
-  emit objectSelected(d->currentEquity());
+  emit selectByObject(d->currentEquity(), eView::Intent::None);
 }
 
 void KInvestmentView::slotSecuritySelected(const QModelIndex &current, const QModelIndex &previous)
@@ -211,7 +227,7 @@ void KInvestmentView::slotLoadAccount(const QString &id)
     d->ui->m_equitiesTree->setRootIndex(indexList.first());
     d->m_idInvAcc = id;
     if (isVisible())
-      emit accountSelected(acc);
+      emit selectByObject(acc, eView::Intent::SynchronizeAccountInLedgersView);
   }
   updateActions(acc);
 }
@@ -234,10 +250,34 @@ void KInvestmentView::slotShowInvestmentMenu(const MyMoneyAccount& acc)
   pMenus[eMenu::Menu::Investment]->exec(QCursor::pos());
 }
 
+void KInvestmentView::slotSelectByObject(const MyMoneyObject& obj, eView::Intent intent)
+{
+  switch(intent) {
+    case eView::Intent::UpdateActions:
+      updateActions(obj);
+      break;
+
+    case eView::Intent::SynchronizeAccountInInvestmentView:
+      if (KMyMoneySettings::syncLedgerInvestment())
+        slotSelectAccount(obj);
+      break;
+
+    case eView::Intent::OpenContextMenu:
+      slotShowInvestmentMenu(static_cast<const MyMoneyAccount&>(obj));
+      break;
+
+    default:
+      break;
+  }
+}
+
 void KInvestmentView::slotNewInvestment()
 {
   Q_D(KInvestmentView);
-  KNewInvestmentWizard::newInvestment(d->m_currentEquity);
+  if (!isVisible())
+    KNewInvestmentWizard::newInvestment(d->m_currentEquity);
+  else
+    KNewInvestmentWizard::newInvestment(MyMoneyFile::instance()->account(d->m_idInvAcc));
 }
 
 void KInvestmentView::slotEditInvestment()
@@ -261,7 +301,7 @@ void KInvestmentView::slotDeleteInvestment()
       file->removeAccount(d->m_currentEquity);
       ft.commit();
     } catch (const MyMoneyException &e) {
-      KMessageBox::information(this, i18n("Unable to delete investment: %1", e.what()));
+      KMessageBox::information(this, i18n("Unable to delete investment: %1", QString::fromLatin1(e.what())));
     }
   } else {
     // we should not keep the 'no' setting because that can confuse people like
@@ -303,7 +343,7 @@ void KInvestmentView::slotUpdatePriceManually()
       calc->exec();
       delete calc;
     } catch (const MyMoneyException &e) {
-      qDebug("Error in price update: %s", qPrintable(e.what()));
+      qDebug("Error in price update: %s", e.what());
     }
   }
 }
