@@ -104,7 +104,6 @@ void KPayeesView::slotChooseDefaultAccount()
       MyMoneySplit s = t->transaction().splitByPayee(d->m_payee.id());
       const MyMoneyAccount& acc = file->account(s.accountId());
 
-      QString txt;
       if (s.action() != MyMoneySplit::actionName(eMyMoney::Split::Action::Amortization)
           && acc.accountType() != eMyMoney::Account::Type::AssetLoan
           && !file->isTransfer(t->transaction())
@@ -291,6 +290,10 @@ void KPayeesView::slotSelectPayee()
 
     d->ui->addressEdit->setEnabled(true);
     d->ui->addressEdit->setText(d->m_payee.address());
+    d->ui->payeecityEdit->setEnabled(true);
+    d->ui->payeecityEdit->setText(d->m_payee.city());
+    d->ui->payeestateEdit->setEnabled(true);
+    d->ui->payeestateEdit->setText(d->m_payee.state());
     d->ui->postcodeEdit->setEnabled(true);
     d->ui->postcodeEdit->setText(d->m_payee.postcode());
     d->ui->telephoneEdit->setEnabled(true);
@@ -308,7 +311,7 @@ void KPayeesView::slotSelectPayee()
     d->ui->matchKeyEditList->insertStringList(keys);
     d->ui->checkMatchIgnoreCase->setChecked(ignorecase);
 
-    d->ui->checkEnableDefaultCategory->setChecked(d->m_payee.defaultAccountEnabled());
+    d->ui->checkEnableDefaultCategory->setChecked(!d->m_payee.defaultAccountId().isEmpty());
     d->ui->comboDefaultCategory->setSelected(d->m_payee.defaultAccountId());
 
     d->ui->payeeIdentifiers->setSource(d->m_payee);
@@ -350,6 +353,10 @@ void KPayeesView::slotPayeeDataChanged()
            || (!d->ui->emailEdit->text().isEmpty() && d->m_payee.email() != d->ui->emailEdit->text()));
     rc |= ((d->m_payee.address().isEmpty() != d->ui->addressEdit->toPlainText().isEmpty())
            || (!d->ui->addressEdit->toPlainText().isEmpty() && d->m_payee.address() != d->ui->addressEdit->toPlainText()));
+    rc |= ((d->m_payee.city().isEmpty() != d->ui->payeecityEdit->text().isEmpty())
+           || (!d->ui->payeecityEdit->text().isEmpty() && d->m_payee.city() != d->ui->payeecityEdit->text()));
+    rc |= ((d->m_payee.state().isEmpty() != d->ui->payeestateEdit->text().isEmpty())
+           || (!d->ui->payeestateEdit->text().isEmpty() && d->m_payee.state() != d->ui->payeestateEdit->text()));
     rc |= ((d->m_payee.postcode().isEmpty() != d->ui->postcodeEdit->text().isEmpty())
            || (!d->ui->postcodeEdit->text().isEmpty() && d->m_payee.postcode() != d->ui->postcodeEdit->text()));
     rc |= ((d->m_payee.telephone().isEmpty() != d->ui->telephoneEdit->text().isEmpty())
@@ -381,7 +388,7 @@ void KPayeesView::slotPayeeDataChanged()
       }
     }
 
-    rc |= (d->ui->checkEnableDefaultCategory->isChecked() != d->m_payee.defaultAccountEnabled());
+    rc |= (d->ui->checkEnableDefaultCategory->isChecked() != !d->m_payee.defaultAccountId().isEmpty());
     if (d->ui->checkEnableDefaultCategory->isChecked()) {
       d->ui->comboDefaultCategory->setEnabled(true);
       d->ui->labelDefaultCategory->setEnabled(true);
@@ -412,6 +419,8 @@ void KPayeesView::slotUpdatePayee()
     try {
       d->m_payee.setName(d->m_newName);
       d->m_payee.setAddress(d->ui->addressEdit->toPlainText());
+      d->m_payee.setCity(d->ui->payeecityEdit->text());
+      d->m_payee.setState(d->ui->payeestateEdit->text());
       d->m_payee.setPostcode(d->ui->postcodeEdit->text());
       d->m_payee.setTelephone(d->ui->telephoneEdit->text());
       d->m_payee.setEmail(d->ui->emailEdit->text());
@@ -452,6 +461,8 @@ void KPayeesView::slotSyncAddressBook()
     if (auto item = dynamic_cast<KPayeeListItem*>(d->ui->m_payeesList->currentItem())) { // update ui if something is selected
       d->m_payee = item->payee();
       d->ui->addressEdit->setText(d->m_payee.address());
+      d->ui->payeecityEdit->setText(d->m_payee.city());
+      d->ui->payeestateEdit->setText(d->m_payee.state());
       d->ui->postcodeEdit->setText(d->m_payee.postcode());
       d->ui->telephoneEdit->setText(d->m_payee.telephone());
     }
@@ -476,8 +487,8 @@ void KPayeesView::slotContactFetched(const ContactData &identity)
       txt.append(identity.street + '\n');
     if (!identity.locality.isEmpty()) {
       txt.append(identity.locality);
-      if (!identity.postalCode.isEmpty())
-        txt.append(' ' + identity.postalCode + '\n');
+    if (!identity.postalCode.isEmpty())
+      txt.append(' ' + identity.postalCode + '\n');
       else
         txt.append('\n');
     }
@@ -487,6 +498,12 @@ void KPayeesView::slotContactFetched(const ContactData &identity)
     if (!txt.isEmpty() && d->m_payee.address().compare(txt) != 0)
       d->m_payee.setAddress(txt);
 
+    if (!identity.city.isEmpty() && d->m_payee.city().compare(identity.city) != 0)
+      d->m_payee.setCity(identity.city);
+
+    if (!identity.state.isEmpty() && d->m_payee.state().compare(identity.state) != 0)
+      d->m_payee.setState(identity.state);
+
     if (!identity.postalCode.isEmpty() && d->m_payee.postcode().compare(identity.postalCode) != 0)
       d->m_payee.setPostcode(identity.postalCode);
 
