@@ -492,7 +492,6 @@ public:
 
       QWidget* parent = QApplication::activeWindow();
       QPointer<KEnterScheduleDlg> dlg = new KEnterScheduleDlg(parent, schedule);
-      qDebug() << "parent widget" << (void*) parent;
 
       try {
         QDate origDueDate = schedule.nextDueDate();
@@ -507,14 +506,14 @@ public:
               schedule.transaction().splits().isEmpty() ? MyMoneySplit() : schedule.transaction().splits().front(), true);
           // force actions to be available no matter what (will be updated according to the state during
           // slotTransactionsEnter or slotTransactionsCancel)
-          pActions[eMenu::Action::CancelTransaction]->setEnabled(true);
-          pActions[eMenu::Action::EnterTransaction]->setEnabled(true);
 
           KConfirmManualEnterDlg::Action action = KConfirmManualEnterDlg::ModifyOnce;
           if (!autoEnter || !schedule.isFixed()) {
             for (; dlg != 0;) {
               rc = eDialogs::ScheduleResultCode::Cancel;
               if (dlg->exec() == QDialog::Accepted && dlg != 0) {
+                pActions[eMenu::Action::CancelTransaction]->setEnabled(true);
+                pActions[eMenu::Action::EnterTransaction]->setEnabled(true);
                 rc = dlg->resultCode();
                 if (rc == eDialogs::ScheduleResultCode::Enter) {
                   transactionEditor->createTransaction(taccepted, torig, torig.splits().isEmpty() ? MyMoneySplit() : torig.splits().front(), true);
@@ -541,6 +540,8 @@ public:
                   slotTransactionsCancel(transactionEditor, schedule);
                 }
               } else {
+                pActions[eMenu::Action::CancelTransaction]->setEnabled(true);
+                pActions[eMenu::Action::EnterTransaction]->setEnabled(true);
                 if (autoEnter) {
                   if (KMessageBox::warningYesNo(q, i18n("Are you sure you wish to stop this scheduled transaction from being entered into the register?\n\nKMyMoney will prompt you again next time it starts unless you manually enter it later.")) == KMessageBox::No) {
                     // the user has chosen 'No' for the above question,
@@ -639,13 +640,15 @@ public:
   void skipSchedule(MyMoneySchedule& schedule)
   {
     Q_Q(KScheduledView);
+    const auto parentWidget = QApplication::activeWindow();
+
     if (!schedule.id().isEmpty()) {
       try {
         schedule = MyMoneyFile::instance()->schedule(schedule.id());
         if (!schedule.isFinished()) {
           if (schedule.occurrence() != eMyMoney::Schedule::Occurrence::Once) {
             QDate next = schedule.nextDueDate();
-            if (!schedule.isFinished() && (KMessageBox::questionYesNo(q, i18n("<qt>Do you really want to skip the <b>%1</b> transaction scheduled for <b>%2</b>?</qt>", schedule.name(), QLocale().toString(next, QLocale::ShortFormat)))) == KMessageBox::Yes) {
+            if (!schedule.isFinished() && (KMessageBox::questionYesNo(parentWidget, i18n("<qt>Do you really want to skip the <b>%1</b> transaction scheduled for <b>%2</b>?</qt>", schedule.name(), QLocale().toString(next, QLocale::ShortFormat)))) == KMessageBox::Yes) {
               MyMoneyFileTransaction ft;
               schedule.setLastPayment(next);
               schedule.setNextDueDate(schedule.nextPayment(next));
@@ -655,7 +658,7 @@ public:
           }
         }
       } catch (const MyMoneyException &e) {
-        KMessageBox::detailedSorry(q, i18n("<qt>Unable to skip scheduled transaction <b>%1</b>.</qt>", schedule.name()), e.what());
+        KMessageBox::detailedSorry(parentWidget, i18n("<qt>Unable to skip scheduled transaction <b>%1</b>.</qt>", schedule.name()), e.what());
       }
     }
   }
