@@ -2,6 +2,7 @@
  * Copyright 2006       Darren Gould <darren_gould@gmx.de>
  * Copyright 2009-2014  Alvaro Soliverez <asoliverez@gmail.com>
  * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ * Copyright 2020       Robert Szczesiak <dev.rszczesiak@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -62,6 +63,7 @@ public:
 BudgetViewProxyModel::BudgetViewProxyModel(QObject *parent) :
   AccountsViewProxyModel(*new BudgetViewProxyModelPrivate, parent)
 {
+  setFilterCaseSensitivity(Qt::CaseInsensitive);
 }
 
 BudgetViewProxyModel::~BudgetViewProxyModel()
@@ -78,12 +80,12 @@ QVariant BudgetViewProxyModel::data(const QModelIndex &index, int role) const
   if (!MyMoneyFile::instance()->storageAttached())
     return QVariant();
   const auto sourceColumn = d->m_mdlColumns->at(mapToSource(index).column());
+  auto const file = MyMoneyFile::instance();
+  const auto ixAccount = mapToSource(BudgetViewProxyModel::index(index.row(), static_cast<int>(Column::Account), index.parent()));
+  const auto account = ixAccount.data((int)Role::Account).value<MyMoneyAccount>();
+
   static QVector<Column> columnsToProcess {Column::TotalBalance, Column::TotalValue/*, AccountsModel::PostedValue, Column::Account*/};
   if (columnsToProcess.contains(sourceColumn)) {
-        const auto ixAccount = mapToSource(BudgetViewProxyModel::index(index.row(), static_cast<int>(Column::Account), index.parent()));
-        const auto account = ixAccount.data((int)Role::Account).value<MyMoneyAccount>();
-        auto const file = MyMoneyFile::instance();
-
         switch (role) {
           case Qt::DisplayRole:
             {
@@ -103,19 +105,23 @@ QVariant BudgetViewProxyModel::data(const QModelIndex &index, int role) const
               }
               break;
             }
-          case (int)Role::Balance:
-            if (file->security(account.currencyId()) != file->baseCurrency())
-              return QVariant::fromValue(accountBalance(account.id()));
-            else
-              return QVariant();
-          case (int)Role::TotalValue:
-            return QVariant::fromValue(computeTotalValue(ixAccount));
-          case (int)Role::Value:
-            return QVariant::fromValue(accountValue(account, accountBalance(account.id())));
           default:
             break;
         }
   }
+  switch (role) {
+    case (int)Role::Balance:
+      if (file->security(account.currencyId()) != file->baseCurrency())
+        return QVariant::fromValue(accountBalance(account.id()));
+      else
+        return QVariant();
+    case (int)Role::TotalValue:
+      return QVariant::fromValue(computeTotalValue(ixAccount));
+    case (int)Role::Value:
+      return QVariant::fromValue(accountValue(account, accountBalance(account.id())));
+    default:
+      break;
+  }
   return AccountsViewProxyModel::data(index, role);
 }
 
@@ -158,11 +164,14 @@ void BudgetViewProxyModel::setBudget(const MyMoneyBudget& budget)
 bool BudgetViewProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
   Q_D(const BudgetViewProxyModel);
-  if (hideUnusedIncomeExpenseAccounts()) {
-    const auto index = sourceModel()->index(source_row, static_cast<int>(Column::Account), source_parent);
-    const auto accountData = sourceModel()->data(index, (int)Role::Account);
-    if (accountData.canConvert<MyMoneyAccount>()) {
-      const auto account = accountData.value<MyMoneyAccount>();
+  const auto index = sourceModel()->index(source_row, static_cast<int>(Column::Account), source_parent);
+  const auto accountData = sourceModel()->data(index, (int)Role::Account);
+  if (accountData.canConvert<MyMoneyAccount>()) {
+    const auto account = accountData.value<MyMoneyAccount>();
+    if (!account.isIncomeExpense()) {
+      return false;
+    }
+    if (hideUnusedIncomeExpenseAccounts()) {
       MyMoneyMoney balance;
       // find out if the account is budgeted
       const auto budgetAccount = d->m_budget.account(account.id());
@@ -177,15 +186,16 @@ bool BudgetViewProxyModel::filterAcceptsRow(int source_row, const QModelIndex &s
         }
       }
       if (!balance.isZero())
-        return AccountsProxyModel::filterAcceptsRow(source_row, source_parent);
+        return AccountsViewProxyModel::filterAcceptsRow(source_row, source_parent);
+      for (auto i = 0; i < sourceModel()->rowCount(index); ++i) {
+        if (filterAcceptsRow(i, index))
+          return true;
+      }
+      return false;
     }
-    for (auto i = 0; i < sourceModel()->rowCount(index); ++i) {
-      if (filterAcceptsRow(i, index))
-        return AccountsProxyModel::filterAcceptsRow(i, index);
-    }
-    return false;
+    return AccountsViewProxyModel::filterAcceptsRow(source_row, source_parent);
   }
-  return AccountsProxyModel::filterAcceptsRow(source_row, source_parent);
+  return false;
 }
 
 MyMoneyMoney BudgetViewProxyModel::accountBalance(const QString &accountId) const
@@ -230,13 +240,13 @@ void BudgetViewProxyModel::checkBalance()
                                      (int)Role::ID,
                                      MyMoneyFile::instance()->income().id(),
                                      1,
-                                     Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive));
+                                     Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive | Qt::MatchWrap));
 
   QModelIndexList expenseList = match(index(0, 0),
                                       (int)Role::ID,
                                       MyMoneyFile::instance()->expense().id(),
                                       1,
-                                      Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive));
+                                      Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive | Qt::MatchWrap));
 
   MyMoneyMoney balance;
   if (!incomeList.isEmpty() && !expenseList.isEmpty()) {
