@@ -1,25 +1,26 @@
-
-/***************************************************************************
-                             kmymoneyaccountselector.h
-                             -------------------
-    begin                : Thu Sep 18 2003
-    copyright            : (C) 2003 by Thomas Baumgart
-    email                : Thomas Baumgart <ipwizard@users.sourceforge.net>
-                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * Copyright 2003-2018  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef KMYMONEYACCOUNTSELECTOR_H
 #define KMYMONEYACCOUNTSELECTOR_H
 
+#include "kmm_widgets_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -54,7 +55,7 @@ namespace eMyMoney { namespace Account { enum class Type; } }
   *   by marking the account in the view.
   */
 class KMyMoneyAccountSelectorPrivate;
-class KMyMoneyAccountSelector : public KMyMoneySelector
+class KMM_WIDGETS_EXPORT KMyMoneyAccountSelector : public KMyMoneySelector
 {
   Q_OBJECT
   Q_DISABLE_COPY(KMyMoneyAccountSelector)
@@ -153,7 +154,7 @@ private:
 };
 
 class AccountSetPrivate;
-class AccountSet
+class KMM_WIDGETS_EXPORT AccountSet
 {
   Q_DISABLE_COPY(AccountSet)
 
@@ -176,6 +177,7 @@ public:
 
   void setHideClosedAccounts(bool _bool);
   bool isHidingClosedAccounts() const;
+  void setShowInvestments(bool show);
 
 protected:
   int loadSubAccounts(KMyMoneyAccountSelector* selector, QTreeWidgetItem* parent, const QString& key, const QStringList& list);
