@@ -3,6 +3,7 @@
  * Copyright 2010-2016  Cristian Oneț <onet.cristian@gmail.com>
  * Copyright 2010       Alvaro Soliverez <asoliverez@gmail.com>
  * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ * Copyright 2020       Robert Szczesiak <dev.rszczesiak@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -197,7 +198,7 @@ void KMyMoneyMVCCombo::focusOutEvent(QFocusEvent* e)
   Q_D(KMyMoneyMVCCombo);
   // when showing m_completion we'll receive a focus out event even if the focus
   // will still remain at this widget since this widget is the completion's focus proxy
-  // so ignore the focus out event caused by showin a widget of type Qt::Popup
+  // so ignore the focus out event caused by showing a widget of type Qt::Popup
   if (e->reason() == Qt::PopupFocusReason)
     return;
 
@@ -206,7 +207,7 @@ void KMyMoneyMVCCombo::focusOutEvent(QFocusEvent* e)
     return;
   }
 
-  //check if the focus went to a widget in TransactionFrom or in the Register
+  //check if the focus went to a widget in TransactionFrom, in the Register, or on a WizardPage
   if (e->reason() == Qt::MouseFocusReason) {
     QObject *w = this->parent();
     QObject *q = qApp->focusWidget()->parent();
@@ -215,7 +216,7 @@ void KMyMoneyMVCCombo::focusOutEvent(QFocusEvent* e)
       w = w->parent();
     while (q && q->objectName() != "qt_scrollarea_viewport")
       q = q->parent();
-    if (q != w && qApp->focusWidget()->objectName() != "register") {
+    if (q != w && qApp->focusWidget()->parent() != w && qApp->focusWidget()->objectName() != "register") {
       KComboBox::focusOutEvent(e);
       return;
     }
@@ -227,7 +228,7 @@ void KMyMoneyMVCCombo::focusOutEvent(QFocusEvent* e)
       // in case we tab out, we make sure that if the current completion
       // contains the current text that we set the current text to
       // the full completion text but only if the completion box is visible.
-      // BUG 254984 is resolved with the visbility check
+      // BUG 254984 is resolved with the visibility check
       if (e->reason() != Qt::MouseFocusReason) {
         if (d->m_completer->popup() && d->m_completer->popup()->isVisible()
             && d->m_completer->currentCompletion().contains(currentText(), Qt::CaseInsensitive)) {
@@ -256,6 +257,7 @@ void KMyMoneyMVCCombo::focusOutEvent(QFocusEvent* e)
   if (isEditable() && currentText().isEmpty()) {
     QString id = d->m_id;
     d->m_id.clear();
+    setCurrentIndex(-1);
     if (!id.isEmpty())
       emit itemSelected(d->m_id);
     update();
@@ -269,20 +271,21 @@ void KMyMoneyMVCCombo::focusOutEvent(QFocusEvent* e)
 void KMyMoneyMVCCombo::checkCurrentText()
 {
   Q_D(KMyMoneyMVCCombo);
-  if (!contains(currentText())) {
+  const auto payeeName = currentText();
+  if (!contains(payeeName)) {
     QString id;
-    // annouce that we go into a possible dialog to create an object
+    // announce that we go into a possible dialog to create an object
     // This can be used by upstream widgets to disable filters etc.
     emit objectCreation(true);
 
-    emit createItem(currentText(), id);
+    emit createItem(payeeName, id);
 
     // Announce that we return from object creation
     emit objectCreation(false);
 
     // update the field to a possibly created object
     d->m_id = id;
-    addEntry(currentText(), id);
+    addEntry(payeeName, id);
     setCurrentTextById(id);
   }
 }
@@ -298,7 +301,7 @@ void KMyMoneyMVCCombo::addEntry(const QString& newTxt, const QString& id)
       }
     }
     // and insert the new item
-    insertItem(idx - 1, QIcon(), currentText(), id);
+    insertItem(idx - 1, QIcon(), newTxt, id);
 }
 
 void KMyMoneyMVCCombo::setCurrentTextById(const QString& id)
