@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2018  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2002-2019  Thomas Baumgart <tbaumgart@kde.org>
  * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -38,16 +38,15 @@
 #include "mymoneyfile.h"
 #include "mymoneytransaction.h"
 #include "mymoneytransactionfilter.h"
-#include "kmymoneyedit.h"
 #include "kmymoneysettings.h"
 #include "daterangedlg.h"
 
-KTransactionFilter::KTransactionFilter(QWidget *parent, bool withEquityAccounts, bool withDataTab) :
+KTransactionFilter::KTransactionFilter(QWidget *parent, bool withEquityAccounts, bool withInvestments, bool withDataTab) :
   QWidget(parent),
   d_ptr(new KTransactionFilterPrivate(this))
 {
   Q_D(KTransactionFilter);
-  d->init(withEquityAccounts, withDataTab);
+  d->init(withEquityAccounts, withInvestments, withDataTab);
 }
 
 KTransactionFilter::~KTransactionFilter()
@@ -67,9 +66,9 @@ void KTransactionFilter::slotReset()
   d->ui->m_amountEdit->setEnabled(true);
   d->ui->m_amountFromEdit->setEnabled(false);
   d->ui->m_amountToEdit->setEnabled(false);
-  d->ui->m_amountEdit->loadText(QString());
-  d->ui->m_amountFromEdit->loadText(QString());
-  d->ui->m_amountToEdit->loadText(QString());
+  d->ui->m_amountEdit->setText(QString());
+  d->ui->m_amountFromEdit->setText(QString());
+  d->ui->m_amountToEdit->setText(QString());
   d->ui->m_amountButton->setChecked(true);
   d->ui->m_amountRangeButton->setChecked(false);
 
@@ -391,6 +390,10 @@ void KTransactionFilter::resetFilter(MyMoneyReport& rep)
   if (rep.firstState(state))
     d->ui->m_stateBox->setCurrentIndex(state);
 
+  int validity;
+  if (rep.firstValidity(validity))
+    d->ui->m_validityBox->setCurrentIndex(validity);
+
   //
   // Number Filter
   //
@@ -437,18 +440,18 @@ void KTransactionFilter::resetFilter(MyMoneyReport& rep)
       d->ui->m_amountEdit->setEnabled(true);
       d->ui->m_amountFromEdit->setEnabled(false);
       d->ui->m_amountToEdit->setEnabled(false);
-      d->ui->m_amountEdit->loadText(QString::number(from.toDouble()));
-      d->ui->m_amountFromEdit->loadText(QString());
-      d->ui->m_amountToEdit->loadText(QString());
+      d->ui->m_amountEdit->setText(QString::number(from.toDouble()));
+      d->ui->m_amountFromEdit->setText(QString());
+      d->ui->m_amountToEdit->setText(QString());
       d->ui->m_amountButton->setChecked(true);
       d->ui->m_amountRangeButton->setChecked(false);
     } else {
       d->ui->m_amountEdit->setEnabled(false);
       d->ui->m_amountFromEdit->setEnabled(true);
       d->ui->m_amountToEdit->setEnabled(true);
-      d->ui->m_amountEdit->loadText(QString());
-      d->ui->m_amountFromEdit->loadText(QString::number(from.toDouble()));
-      d->ui->m_amountToEdit->loadText(QString::number(to.toDouble()));
+      d->ui->m_amountEdit->setText(QString());
+      d->ui->m_amountFromEdit->setText(QString::number(from.toDouble()));
+      d->ui->m_amountToEdit->setText(QString::number(to.toDouble()));
       d->ui->m_amountButton->setChecked(false);
       d->ui->m_amountRangeButton->setChecked(true);
     }
@@ -456,9 +459,9 @@ void KTransactionFilter::resetFilter(MyMoneyReport& rep)
     d->ui->m_amountEdit->setEnabled(true);
     d->ui->m_amountFromEdit->setEnabled(false);
     d->ui->m_amountToEdit->setEnabled(false);
-    d->ui->m_amountEdit->loadText(QString());
-    d->ui->m_amountFromEdit->loadText(QString());
-    d->ui->m_amountToEdit->loadText(QString());
+    d->ui->m_amountEdit->setText(QString());
+    d->ui->m_amountFromEdit->setText(QString());
+    d->ui->m_amountToEdit->setText(QString());
     d->ui->m_amountButton->setChecked(true);
     d->ui->m_amountRangeButton->setChecked(false);
   }
