@@ -34,7 +34,6 @@
 
 #include "ui_ktransactionfilter.h"
 
-#include "kmymoneyedit.h"
 #include "mymoneyaccount.h"
 #include "mymoneyfile.h"
 #include "mymoneypayee.h"
@@ -75,7 +74,7 @@ public:
     delete ui;
   }
 
-  void init(bool withEquityAccounts, bool withDataTab)
+  void init(bool withEquityAccounts, bool withInvestments, bool withDataTab)
   {
     Q_Q(KTransactionFilter);
     ui->setupUi(q);
@@ -93,7 +92,7 @@ public:
     // 'cause we don't have a separate setupTextPage
     q->connect(ui->m_textEdit, &QLineEdit::textChanged, q, &KTransactionFilter::slotUpdateSelections);
 
-    setupAccountsPage(withEquityAccounts);
+    setupAccountsPage(withEquityAccounts, withInvestments);
     setupCategoriesPage();
     setupAmountPage();
     setupPayeesPage();
@@ -361,9 +360,9 @@ public:
     q->connect(ui->m_amountButton, &QAbstractButton::clicked, q, &KTransactionFilter::slotAmountSelected);
     q->connect(ui->m_amountRangeButton, &QAbstractButton::clicked, q, &KTransactionFilter::slotAmountRangeSelected);
 
-    q->connect(ui->m_amountEdit,      &KMyMoneyEdit::textChanged, q, &KTransactionFilter::slotUpdateSelections);
-    q->connect(ui->m_amountFromEdit,  &KMyMoneyEdit::textChanged, q, &KTransactionFilter::slotUpdateSelections);
-    q->connect(ui->m_amountToEdit,    &KMyMoneyEdit::textChanged, q, &KTransactionFilter::slotUpdateSelections);
+    q->connect(ui->m_amountEdit,      &AmountEdit::textChanged, q, &KTransactionFilter::slotUpdateSelections);
+    q->connect(ui->m_amountFromEdit,  &AmountEdit::textChanged, q, &KTransactionFilter::slotUpdateSelections);
+    q->connect(ui->m_amountToEdit,    &AmountEdit::textChanged, q, &KTransactionFilter::slotUpdateSelections);
 
     ui->m_amountButton->setChecked(true);
     q->slotAmountSelected();
@@ -380,7 +379,7 @@ public:
     q->connect(ui->m_categoriesView, &KMyMoneyAccountSelector::stateChanged, q, &KTransactionFilter::slotUpdateSelections);
   }
 
-  void setupAccountsPage(bool withEquityAccounts)
+  void setupAccountsPage(bool withEquityAccounts, bool withInvestments)
   {
     Q_Q(KTransactionFilter);
     ui->m_accountsView->setSelectionMode(QTreeWidget::MultiSelection);
@@ -392,6 +391,7 @@ public:
 
     // set the accountset to show closed account if the settings say so
     accountSet.setHideClosedAccounts(KMyMoneySettings::hideClosedAccounts() && !KMyMoneySettings::showAllAccounts());
+    accountSet.setShowInvestments(withInvestments);
     accountSet.load(ui->m_accountsView);
     q->connect(ui->m_accountsView, &KMyMoneyAccountSelector::stateChanged, q, &KTransactionFilter::slotUpdateSelections);
   }
