@@ -1,12 +1,11 @@
 /*
- * This file is part of KMyMoney, A Personal Finance Manager by KDE
- * Copyright (C) 2015  Christian David <christian-david@web.de>
- * (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+ * Copyright 2015       Christian Dávid <christian-david@web.de>
+ * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +35,7 @@ protected Q_SLOTS:
    *
    * After widgets are created, this version finds the label and renames it to "Filter"
    */
-  virtual void createWidgets();
+  void createWidgets() final override;
 };
 
 #endif // KTREEWIDGETFILTERLINEWIDGET_H
