@@ -51,7 +51,6 @@
 #include "kmymoneycategory.h"
 #include "kmymoneydateinput.h"
 #include "transactionform.h"
-#include "kmymoneyedit.h"
 #include "kmymoneyutils.h"
 #include "registerfilter.h"
 #include "tabbar.h"
@@ -450,7 +449,7 @@ void Transaction::paintRegisterCell(QPainter *painter, QStyleOptionViewItem &opt
     // construct the text for the cell
     QString txt;
     option.displayAlignment = Qt::AlignVCenter;
-    if (d->m_transaction != MyMoneyTransaction() && !d->m_inRegisterEdit) {
+    if (!d->m_transaction.id().isEmpty() && !d->m_inRegisterEdit) {
       registerCellText(txt, option.displayAlignment, index.row() - startRow(), index.column(), painter);
     }
 
@@ -720,7 +719,7 @@ QString Transaction::reconcileState(bool text) const
 
   if ((text == true)
       && (txt == i18nc("Unknown reconciliation state", "Unknown"))
-      && (d->m_transaction == MyMoneyTransaction()))
+      && (d->m_transaction.id().isEmpty()))
     txt.clear();
   return txt;
 }
@@ -843,7 +842,7 @@ bool Transaction::matches(const RegisterFilter& filter) const
       }
     }
     const MyMoneyAccount& acc = file->account(split.accountId());
-    // search for account hierachy
+    // search for account hierarchy
     if (filter.text.contains(MyMoneyFile::AccountSeparator)) {
       QStringList names;
       MyMoneyAccount current = acc;
