@@ -42,7 +42,6 @@
 #include "mymoneyexception.h"
 #include "mymoneyutils.h"
 #include "mymoneytracer.h"
-#include "kmymoneyedit.h"
 #include "mymoneysplit.h"
 #include "mymoneyfile.h"
 #include "mymoneyinstitution.h"
@@ -403,7 +402,7 @@ bool KEndingBalanceDlg::createTransaction(MyMoneyTransaction &t, const int sign,
     t.modifySplit(s2);
 
   } catch (const MyMoneyException &e) {
-    qDebug("%s", qPrintable(e.what()));
+    qDebug("%s", e.what());
     t = MyMoneyTransaction();
     return false;
   }
