@@ -80,7 +80,7 @@ KInvestmentDetailsWizardPage::KInvestmentDetailsWizardPage(QWidget *parent) :
   registerField("roundingMethod", ui->m_roundingMethod, "currentData", SIGNAL(currentIndexChanged(int)));
 
   registerField("fraction", ui->m_fraction, "value", SIGNAL(textChanged()));
-  connect(ui->m_fraction, &KMyMoneyEdit::textChanged,
+  connect(ui->m_fraction, &AmountEdit::textChanged,
           this, &QWizardPage::completeChanged);
 
   registerField("pricePrecision", ui->m_pricePrecision, "value", SIGNAL(valueChanged()));
@@ -96,8 +96,18 @@ KInvestmentDetailsWizardPage::~KInvestmentDetailsWizardPage()
  */
 void KInvestmentDetailsWizardPage::init2(const MyMoneySecurity& security)
 {
-  MyMoneySecurity tradingCurrency = MyMoneyFile::instance()->currency(security.tradingCurrency());
+  const auto file = MyMoneyFile::instance();
+  MyMoneySecurity tradingCurrency = file->currency(security.tradingCurrency());
   ui->m_investmentSymbol->setText(security.tradingSymbol());
+  // add any trading market found in the data to the combo box
+  const auto securities = file->securityList();
+  for(const auto& sec: securities) {
+    if (!sec.tradingMarket().isEmpty()) {
+      if (ui->m_tradingMarket->findText(sec.tradingMarket(), Qt::MatchExactly) == -1) {
+        ui->m_tradingMarket->addItem(sec.tradingMarket());
+      }
+    }
+  }
   ui->m_tradingMarket->setCurrentIndex(ui->m_tradingMarket->findText(security.tradingMarket(), Qt::MatchExactly));
   if (security.roundingMethod() == AlkValue::RoundNever)
     ui->m_roundingMethod->setCurrentIndex(0);
