@@ -40,8 +40,8 @@ KOnlineUpdateWizardPage::KOnlineUpdateWizardPage(QWidget *parent) :
   ui(new Ui::KOnlineUpdateWizardPage)
 {
   ui->setupUi(this);
-  ui->m_onlineFactor->setValue(MyMoneyMoney::ONE);
   ui->m_onlineFactor->setPrecision(4);
+  ui->m_onlineFactor->setValue(MyMoneyMoney::ONE);
 
   // make ui->m_onlineSourceCombo sortable
   QSortFilterProxyModel* proxy = new QSortFilterProxyModel(ui->m_onlineSourceCombo);
@@ -59,7 +59,7 @@ KOnlineUpdateWizardPage::KOnlineUpdateWizardPage(QWidget *parent) :
   registerField("onlineSourceCombo", ui->m_onlineSourceCombo, "currentText", SIGNAL(currentIndexChanged(QString)));
   registerField("useFinanceQuote", ui->m_useFinanceQuote);
   connect(ui->m_onlineSourceCombo, static_cast<void (QComboBox::*)(const QString&)>(&QComboBox::currentIndexChanged), this, &KOnlineUpdateWizardPage::slotCheckPage);
-  connect(ui->m_onlineFactor, &KMyMoneyEdit::textChanged,
+  connect(ui->m_onlineFactor, &AmountEdit::textChanged,
           this, &QWizardPage::completeChanged);
 
   connect(ui->m_onlineSourceCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
